@@ -54,7 +54,6 @@ struct _GsAppClass
  * @GS_APP_KUDO_INSTALLS_USER_DOCS:	Installs user docs
  * @GS_APP_KUDO_USES_NOTIFICATIONS:	Registers notifications
  * @GS_APP_KUDO_HAS_KEYWORDS:		Has at least 1 keyword
- * @GS_APP_KUDO_USES_APP_MENU:		Uses an AppMenu for navigation
  * @GS_APP_KUDO_HAS_SCREENSHOTS:	Supplies screenshots
  * @GS_APP_KUDO_POPULAR:		Is popular
  * @GS_APP_KUDO_HIGH_CONTRAST:		Installs a high contrast icon
@@ -73,7 +72,6 @@ typedef enum {
 	GS_APP_KUDO_INSTALLS_USER_DOCS		= 1 << 5,
 	GS_APP_KUDO_USES_NOTIFICATIONS		= 1 << 6,
 	GS_APP_KUDO_HAS_KEYWORDS		= 1 << 7,
-	GS_APP_KUDO_USES_APP_MENU		= 1 << 8,
 	GS_APP_KUDO_HAS_SCREENSHOTS		= 1 << 9,
 	GS_APP_KUDO_POPULAR			= 1 << 10,
 	GS_APP_KUDO_HIGH_CONTRAST		= 1 << 13,
@@ -84,6 +82,46 @@ typedef enum {
 	GS_APP_KUDO_LAST
 } GsAppKudo;
 
+/**
+ * GsAppQuirk:
+ * @GS_APP_QUIRK_NONE:			No special attributes
+ * @GS_APP_QUIRK_PROVENANCE:		Installed by OS vendor
+ * @GS_APP_QUIRK_COMPULSORY:		Cannot be removed
+ * @GS_APP_QUIRK_HAS_SOURCE:		Has a source to allow staying up-to-date
+ * @GS_APP_QUIRK_IS_WILDCARD:		Matches applications from any plugin
+ * @GS_APP_QUIRK_NEEDS_REBOOT:		A reboot is required after the action
+ * @GS_APP_QUIRK_NOT_REVIEWABLE:	The app is not reviewable
+ * @GS_APP_QUIRK_HAS_SHORTCUT:		The app has a shortcut in the system
+ * @GS_APP_QUIRK_NOT_LAUNCHABLE:	The app is not launchable (run-able)
+ * @GS_APP_QUIRK_NEEDS_USER_ACTION:	The component requires some kind of user action
+ * @GS_APP_QUIRK_IS_PROXY:		Is a proxy app that operates on other applications
+ * @GS_APP_QUIRK_REMOVABLE_HARDWARE:	The device is unusable whilst the action is performed
+ * @GS_APP_QUIRK_DEVELOPER_VERIFIED:	The app developer has been verified
+ * @GS_APP_QUIRK_PARENTAL_FILTER:	The app has been filtered by parental controls, and should be hidden
+ * @GS_APP_QUIRK_NEW_PERMISSIONS:	The update requires new permissions
+ *
+ * The application attributes.
+ **/
+typedef enum {
+	GS_APP_QUIRK_NONE		= 0,		/* Since: 3.32 */
+	GS_APP_QUIRK_PROVENANCE		= 1 << 0,	/* Since: 3.32 */
+	GS_APP_QUIRK_COMPULSORY		= 1 << 1,	/* Since: 3.32 */
+	GS_APP_QUIRK_HAS_SOURCE		= 1 << 2,	/* Since: 3.32 */
+	GS_APP_QUIRK_IS_WILDCARD	= 1 << 3,	/* Since: 3.32 */
+	GS_APP_QUIRK_NEEDS_REBOOT	= 1 << 4,	/* Since: 3.32 */
+	GS_APP_QUIRK_NOT_REVIEWABLE	= 1 << 5,	/* Since: 3.32 */
+	GS_APP_QUIRK_HAS_SHORTCUT	= 1 << 6,	/* Since: 3.32 */
+	GS_APP_QUIRK_NOT_LAUNCHABLE	= 1 << 7,	/* Since: 3.32 */
+	GS_APP_QUIRK_NEEDS_USER_ACTION	= 1 << 8,	/* Since: 3.32 */
+	GS_APP_QUIRK_IS_PROXY 		= 1 << 9,	/* Since: 3.32 */
+	GS_APP_QUIRK_REMOVABLE_HARDWARE	= 1 << 10,	/* Since: 3.32 */
+	GS_APP_QUIRK_DEVELOPER_VERIFIED	= 1 << 11,	/* Since: 3.32 */
+	GS_APP_QUIRK_PARENTAL_FILTER	= 1 << 12,	/* Since: 3.32 */
+	GS_APP_QUIRK_NEW_PERMISSIONS    = 1 << 13,	/* Since: 3.32 */
+	/*< private >*/
+	GS_APP_QUIRK_LAST
+} GsAppQuirk;
+
 #define	GS_APP_INSTALL_DATE_UNSET		0
 #define	GS_APP_INSTALL_DATE_UNKNOWN		1 /* 1s past the epoch */
 #define	GS_APP_SIZE_UNKNOWABLE			G_MAXUINT64
@@ -106,6 +144,32 @@ typedef enum {
 	GS_APP_QUALITY_LAST
 } GsAppQuality;
 
+typedef enum {
+	GS_APP_PERMISSIONS_NONE 		= 0,
+	GS_APP_PERMISSIONS_UNKNOWN		= 1 << 0,
+	GS_APP_PERMISSIONS_NETWORK 		= 1 << 1,
+	GS_APP_PERMISSIONS_SYSTEM_BUS   	= 1 << 2,
+	GS_APP_PERMISSIONS_SESSION_BUS		= 1 << 3,
+	GS_APP_PERMISSIONS_DEVICES 		= 1 << 4,
+	GS_APP_PERMISSIONS_HOME_FULL 		= 1 << 5,
+	GS_APP_PERMISSIONS_HOME_READ		= 1 << 6,
+	GS_APP_PERMISSIONS_FILESYSTEM_FULL	= 1 << 7,
+	GS_APP_PERMISSIONS_FILESYSTEM_READ	= 1 << 8,
+	GS_APP_PERMISSIONS_DOWNLOADS_FULL 	= 1 << 9,
+	GS_APP_PERMISSIONS_DOWNLOADS_READ	= 1 << 10,
+	GS_APP_PERMISSIONS_SETTINGS		= 1 << 11,
+	GS_APP_PERMISSIONS_X11			= 1 << 12,
+	/*< private >*/
+	GS_APP_PERMISSIONS_LAST
+} GsAppPermissions;
+
+#define LIMITED_PERMISSIONS (GS_APP_PERMISSIONS_SETTINGS | \
+			GS_APP_PERMISSIONS_NETWORK | \
+			GS_APP_PERMISSIONS_DOWNLOADS_READ | \
+			GS_APP_PERMISSIONS_DOWNLOADS_FULL)
+#define MEDIUM_PERMISSIONS (LIMITED_PERMISSIONS | \
+			GS_APP_PERMISSIONS_X11)
+
 GsApp		*gs_app_new			(const gchar	*id);
 G_DEPRECATED_FOR(gs_app_set_from_unique_id)
 GsApp		*gs_app_new_from_unique_id	(const gchar	*unique_id);
@@ -313,15 +377,24 @@ void		 gs_app_set_match_value		(GsApp		*app,
 guint		 gs_app_get_match_value		(GsApp		*app);
 
 gboolean	 gs_app_has_quirk		(GsApp		*app,
-						 AsAppQuirk	 quirk);
+						 GsAppQuirk	 quirk);
 void		 gs_app_add_quirk		(GsApp		*app,
-						 AsAppQuirk	 quirk);
+						 GsAppQuirk	 quirk);
 void		 gs_app_remove_quirk		(GsApp		*app,
-						 AsAppQuirk	 quirk);
+						 GsAppQuirk	 quirk);
 gboolean	 gs_app_is_installed		(GsApp		*app);
 gboolean	 gs_app_is_updatable		(GsApp		*app);
 gchar		*gs_app_get_origin_ui		(GsApp		*app);
 gchar		*gs_app_get_packaging_format	(GsApp		*app);
+void		 gs_app_subsume_metadata	(GsApp		*app,
+						 GsApp		*donor);
+GsAppPermissions gs_app_get_permissions		(GsApp		*app);
+void		 gs_app_set_permissions		(GsApp		*app,
+						 GsAppPermissions permissions);
+GsAppPermissions gs_app_get_update_permissions	(GsApp		*app);
+void		 gs_app_set_update_permissions	(GsApp		*app,
+						 GsAppPermissions update_permissions);
+
 G_END_DECLS
 
 #endif /* __GS_APP_H */
