@@ -681,7 +681,7 @@ gboolean	 gs_plugin_app_set_rating		(GsPlugin	*plugin,
  * NOTE: Once the action is complete, the plugin must set the new state of @app
  * to %AS_APP_STATE_INSTALLED or %AS_APP_STATE_UNKNOWN if not known.
  *
- * If %AS_APP_QUIRK_IS_PROXY is set on the application then the actual #GsApp
+ * If %GS_APP_QUIRK_IS_PROXY is set on the application then the actual #GsApp
  * set in @app will be the related application of the parent. Plugins do not
  * need to manually iterate on the related list of applications.
  *
@@ -977,70 +977,6 @@ gboolean	 gs_plugin_update			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_auth_login:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs a login using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_login			(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_logout:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs a logout using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_logout			(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_lost_password:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs the lost password action using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_lost_password		(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
-/**
- * gs_plugin_auth_register:
- * @plugin: a #GsPlugin
- * @auth: a #GsAuth
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Performs the registration action using the given authentication details.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_auth_register		(GsPlugin	*plugin,
-							 GsAuth		*auth,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 G_END_DECLS
 
 #endif /* __GS_PLUGIN_VFUNCS_H */
