@@ -89,7 +89,7 @@ void		 gs_plugin_set_soup_session		(GsPlugin	*plugin,
 void		 gs_plugin_add_auth			(GsPlugin	*plugin,
 							 GsAuth		*auth);
 GsAuth		*gs_plugin_get_auth_by_id		(GsPlugin	*plugin,
-							 const gchar	*provider_id);
+							 const gchar	*auth_id);
 void		 gs_plugin_add_rule			(GsPlugin	*plugin,
 							 GsPluginRule	 rule,
 							 const gchar	*name);
