@@ -144,22 +144,38 @@ gs_utils_cache_func (void)
 static void
 gs_utils_error_func (void)
 {
-	guint i;
+	g_autofree gchar *app_id = NULL;
+	g_autofree gchar *origin_id = NULL;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsApp) app = gs_app_new ("gimp.desktop");
+	g_autoptr(GsApp) origin = gs_app_new ("gimp-repo");
 
-	for (i = 0; i < GS_PLUGIN_ERROR_LAST; i++)
+	for (guint i = 0; i < GS_PLUGIN_ERROR_LAST; i++)
 		g_assert (gs_plugin_error_to_string (i) != NULL);
 
-	gs_utils_error_add_unique_id (&error, app);
+	/* noop */
+	gs_utils_error_add_app_id (&error, app);
+	gs_utils_error_add_origin_id (&error, origin);
+
 	g_set_error (&error,
 		     GS_PLUGIN_ERROR,
 		     GS_PLUGIN_ERROR_DOWNLOAD_FAILED,
 		     "failed");
 	g_assert_cmpstr (error->message, ==, "failed");
-	gs_utils_error_add_unique_id (&error, app);
-	g_assert_cmpstr (error->message, ==, "[*/*/*/*/gimp.desktop/*] failed");
-	gs_utils_error_strip_unique_id (error);
+	gs_utils_error_add_app_id (&error, app);
+	gs_utils_error_add_origin_id (&error, origin);
+	g_assert_cmpstr (error->message, ==, "[*/*/*/*/gimp-repo/*] {*/*/*/*/gimp.desktop/*} failed");
+
+	/* find and strip any unique IDs from the error message */
+	for (guint i = 0; i < 2; i++) {
+		if (app_id == NULL)
+			app_id = gs_utils_error_strip_app_id (error);
+		if (origin_id == NULL)
+			origin_id = gs_utils_error_strip_origin_id (error);
+	}
+
+	g_assert_cmpstr (app_id, ==, "*/*/*/*/gimp.desktop/*");
+	g_assert_cmpstr (origin_id, ==, "*/*/*/*/gimp-repo/*");
 	g_assert_cmpstr (error->message, ==, "failed");
 }
 
@@ -493,7 +509,7 @@ gs_plugin_func (void)
 	/* allow duplicating a wildcard */
 	list = gs_app_list_new ();
 	app = gs_app_new ("gimp.desktop");
-	gs_app_add_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX);
+	gs_app_add_quirk (app, GS_APP_QUIRK_IS_WILDCARD);
 	gs_app_list_add (list, app);
 	g_object_unref (app);
 	app = gs_app_new ("gimp.desktop");
@@ -506,11 +522,11 @@ gs_plugin_func (void)
 	/* allow duplicating a wildcard */
 	list = gs_app_list_new ();
 	app = gs_app_new ("gimp.desktop");
-	gs_app_add_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX);
+	gs_app_add_quirk (app, GS_APP_QUIRK_IS_WILDCARD);
 	gs_app_list_add (list, app);
 	g_object_unref (app);
 	app = gs_app_new ("gimp.desktop");
-	gs_app_add_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX);
+	gs_app_add_quirk (app, GS_APP_QUIRK_IS_WILDCARD);
 	gs_app_list_add (list, app);
 	g_object_unref (app);
 	g_assert_cmpint (gs_app_list_length (list), ==, 1);
@@ -691,54 +707,6 @@ gs_app_func (void)
 	gs_app_set_state_recover (app);
 }
 
-static void
-gs_auth_secret_func (void)
-{
-	gboolean ret;
-	g_autoptr(GDBusConnection) conn = NULL;
-	g_autoptr(GError) error = NULL;
-	g_autoptr(GsAuth) auth1 = NULL;
-	g_autoptr(GsAuth) auth2 = NULL;
-
-	/* we not have an active session bus */
-	conn = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
-	if (conn == NULL) {
-		g_prefix_error (&error, "no session bus available: ");
-		g_test_skip (error->message);
-		return;
-	}
-
-	/* save secrets to disk */
-	auth1 = gs_auth_new ("self-test");
-	gs_auth_set_provider_schema (auth1, "org.gnome.Software.Dummy");
-	gs_auth_set_username (auth1, "hughsie");
-	gs_auth_set_password (auth1, "foobarbaz");
-	gs_auth_add_metadata (auth1, "day", "monday");
-	ret = gs_auth_store_save (auth1,
-				  GS_AUTH_STORE_FLAG_USERNAME |
-				  GS_AUTH_STORE_FLAG_PASSWORD |
-				  GS_AUTH_STORE_FLAG_METADATA,
-				  NULL, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-
-	/* load secrets from disk */
-	auth2 = gs_auth_new ("self-test");
-	gs_auth_add_metadata (auth2, "day", NULL);
-	gs_auth_add_metadata (auth2, "notgoingtoexist", NULL);
-	gs_auth_set_provider_schema (auth2, "org.gnome.Software.Dummy");
-	ret = gs_auth_store_load (auth2,
-				  GS_AUTH_STORE_FLAG_USERNAME |
-				  GS_AUTH_STORE_FLAG_PASSWORD |
-				  GS_AUTH_STORE_FLAG_METADATA,
-				  NULL, &error);
-	g_assert_no_error (error);
-	g_assert (ret);
-	g_assert_cmpstr (gs_auth_get_username (auth2), ==, "hughsie");
-	g_assert_cmpstr (gs_auth_get_password (auth2), ==, "foobarbaz");
-	g_assert_cmpstr (gs_auth_get_metadata_item (auth2, "day"), ==, "monday");
-}
-
 static void
 gs_app_list_func (void)
 {
@@ -815,7 +783,6 @@ main (int argc, char **argv)
 	g_test_add_func ("/gnome-software/lib/app{list-related}", gs_app_list_related_func);
 	g_test_add_func ("/gnome-software/lib/plugin", gs_plugin_func);
 	g_test_add_func ("/gnome-software/lib/plugin{download-rewrite}", gs_plugin_download_rewrite_func);
-	g_test_add_func ("/gnome-software/lib/auth{secret}", gs_auth_secret_func);
 
 	return g_test_run ();
 }
