@@ -57,7 +57,7 @@ gs_plugin_generic_updates_get_os_update (GsPlugin *plugin)
 
 	/* create new */
 	app = gs_app_new (id);
-	gs_app_add_quirk (app, AS_APP_QUIRK_IS_PROXY);
+	gs_app_add_quirk (app, GS_APP_QUIRK_IS_PROXY);
 	gs_app_set_management_plugin (app, "");
 	gs_app_set_kind (app, AS_APP_KIND_OS_UPDATE);
 	gs_app_set_state (app, AS_APP_STATE_UPDATABLE_LIVE);
@@ -98,7 +98,7 @@ gs_plugin_refine (GsPlugin *plugin,
 	/* do we have any packages left that are not apps? */
 	for (guint i = 0; i < gs_app_list_length (list); i++) {
 		GsApp *app_tmp = gs_app_list_index (list, i);
-		if (gs_app_has_quirk (app_tmp, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app_tmp, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		if (gs_plugin_generic_updates_merge_os_update (app_tmp))
 			gs_app_list_add (os_updates, app_tmp);
@@ -113,8 +113,6 @@ gs_plugin_refine (GsPlugin *plugin,
 		const gchar *id = gs_app_get_unique_id (app_tmp);
 		if (id == NULL)
 			id = gs_app_get_source_default (app_tmp);
-		g_debug ("moving %s to parent %s",
-			 id, gs_app_get_unique_id (app));
 		gs_app_add_related (app, app_tmp);
 		gs_app_list_remove (list, app_tmp);
 	}
