@@ -21,6 +21,8 @@
 
 #include "config.h"
 
+#include <glib/gstdio.h>
+
 #include "gnome-software-private.h"
 
 #include "gs-test.h"
@@ -95,15 +97,16 @@ gs_plugins_dummy_install_func (GsPluginLoader *plugin_loader)
 static void
 gs_plugins_dummy_error_func (GsPluginLoader *plugin_loader)
 {
-	GsPluginEvent *event;
 	const GError *app_error;
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) events = NULL;
 	g_autoptr(GsApp) app = NULL;
+	g_autoptr(GsPluginEvent) event = NULL;
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 
 	/* drop all caches */
+	g_unlink ("/var/tmp/self-test/appstream/components.xmlb");
 	gs_plugin_loader_setup_again (plugin_loader);
 
 	/* update, which should cause an error to be emitted */
@@ -186,10 +189,11 @@ gs_plugins_dummy_metadata_quirks (GsPluginLoader *plugin_loader)
 
 	/* check the not-launchable quirk */
 
-	g_assert (!gs_app_has_quirk(app, AS_APP_QUIRK_NOT_LAUNCHABLE));
+	g_assert (!gs_app_has_quirk(app, GS_APP_QUIRK_NOT_LAUNCHABLE));
 
 	gs_app_set_metadata (app, "GnomeSoftware::quirks::not-launchable", "true");
 
+	g_object_unref (plugin_job);
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFINE,
 					 "app", app,
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION,
@@ -199,11 +203,12 @@ gs_plugins_dummy_metadata_quirks (GsPluginLoader *plugin_loader)
 	g_assert_no_error (error);
 	g_assert (ret);
 
-	g_assert (gs_app_has_quirk(app, AS_APP_QUIRK_NOT_LAUNCHABLE));
+	g_assert (gs_app_has_quirk(app, GS_APP_QUIRK_NOT_LAUNCHABLE));
 
 	gs_app_set_metadata (app, "GnomeSoftware::quirks::not-launchable", NULL);
 	gs_app_set_metadata (app, "GnomeSoftware::quirks::not-launchable", "false");
 
+	g_object_unref (plugin_job);
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFINE,
 					 "app", app,
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_DESCRIPTION,
@@ -213,7 +218,7 @@ gs_plugins_dummy_metadata_quirks (GsPluginLoader *plugin_loader)
 	g_assert_no_error (error);
 	g_assert (ret);
 
-	g_assert (!gs_app_has_quirk(app, AS_APP_QUIRK_NOT_LAUNCHABLE));
+	g_assert (!gs_app_has_quirk(app, GS_APP_QUIRK_NOT_LAUNCHABLE));
 }
 
 static void
@@ -292,7 +297,7 @@ gs_plugins_dummy_updates_func (GsPluginLoader *plugin_loader)
 	/* get the virtual non-apps OS update */
 	app = gs_app_list_index (list, 1);
 	g_assert_cmpstr (gs_app_get_id (app), ==, "proxy.desktop");
-	g_assert (gs_app_has_quirk (app, AS_APP_QUIRK_IS_PROXY));
+	g_assert (gs_app_has_quirk (app, GS_APP_QUIRK_IS_PROXY));
 	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_UPDATABLE_LIVE);
 	g_assert_cmpint (gs_app_list_length (gs_app_get_related (app)), ==, 2);
 }
@@ -384,7 +389,7 @@ gs_plugins_dummy_installed_func (GsPluginLoader *plugin_loader)
 	g_assert (gs_app_get_pixbuf (app) != NULL);
 
 	/* check various bitfields */
-	g_assert (gs_app_has_quirk (app, AS_APP_QUIRK_PROVENANCE));
+	g_assert (gs_app_has_quirk (app, GS_APP_QUIRK_PROVENANCE));
 	g_assert_cmpstr (gs_app_get_license (app), ==, "GPL-2.0+");
 	g_assert (gs_app_get_license_is_free (app));
 
@@ -424,7 +429,7 @@ gs_plugins_dummy_search_func (GsPluginLoader *plugin_loader)
 
 	/* get search result based on addon keyword */
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_SEARCH,
-					 "search", "spell",
+					 "search", "zeus",
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 					 NULL);
 	list = gs_plugin_loader_job_process (plugin_loader, plugin_job, NULL, &error);
@@ -478,6 +483,7 @@ gs_plugins_dummy_hang_func (GsPluginLoader *plugin_loader)
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 
 	/* drop all caches */
+	g_unlink ("/var/tmp/self-test/appstream/components.xmlb");
 	gs_plugin_loader_setup_again (plugin_loader);
 
 	/* get search result based on addon keyword */
@@ -560,86 +566,6 @@ gs_plugins_dummy_plugin_cache_func (GsPluginLoader *plugin_loader)
 	g_assert (app1 == app2);
 }
 
-static void
-gs_plugins_dummy_authentication_func (GsPluginLoader *plugin_loader)
-{
-	GsAuth *auth;
-	gboolean ret;
-	g_autoptr(GError) error = NULL;
-	g_autoptr(GsApp) app = NULL;
-	g_autoptr(GsAppList) list = NULL;
-	g_autoptr(AsReview) review = NULL;
-	g_autoptr(AsReview) review2 = NULL;
-	g_autoptr(GsPluginJob) plugin_job = NULL;
-
-	/* check initial state */
-	auth = gs_plugin_loader_get_auth_by_id (plugin_loader, "dummy");
-	g_assert (GS_IS_AUTH (auth));
-	g_assert_cmpint (gs_auth_get_flags (auth), ==, 0);
-
-	/* do an action that returns a URL */
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_AUTH_REGISTER,
-					 "auth", auth,
-					 NULL);
-	list = gs_plugin_loader_job_process (plugin_loader, plugin_job, NULL, &error);
-	gs_test_flush_main_context ();
-	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_INVALID);
-	g_assert (list == NULL);
-	g_clear_error (&error);
-	g_assert (!gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID));
-
-	/* do an action that requires a login */
-	app = gs_app_new (NULL);
-	review = as_review_new ();
-	g_object_unref (plugin_job);
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REVIEW_REMOVE,
-					 "app", app,
-					 "review", review,
-					 NULL);
-	ret = gs_plugin_loader_job_action (plugin_loader, plugin_job, NULL, &error);
-	gs_test_flush_main_context ();
-	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_REQUIRED);
-	g_assert (!ret);
-	g_clear_error (&error);
-
-	/* pretend to auth with no credentials */
-	g_object_unref (plugin_job);
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_AUTH_LOGIN,
-					 "auth", auth,
-					 NULL);
-	list = gs_plugin_loader_job_process (plugin_loader, plugin_job, NULL, &error);
-	gs_test_flush_main_context ();
-	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_INVALID);
-	g_assert (list == NULL);
-	g_clear_error (&error);
-	g_assert (!gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID));
-
-	/* auth again with correct credentials */
-	gs_auth_set_username (auth, "dummy");
-	gs_auth_set_password (auth, "dummy");
-	g_object_unref (plugin_job);
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_AUTH_LOGIN,
-						 "auth", auth,
-						 NULL);
-	list = gs_plugin_loader_job_process (plugin_loader, plugin_job, NULL, &error);
-	gs_test_flush_main_context ();
-	g_assert_no_error (error);
-	g_assert (list != NULL);
-	g_assert (gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID));
-
-	/* do the action that requires a login */
-	review2 = as_review_new ();
-	g_object_unref (plugin_job);
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REVIEW_REMOVE,
-					 "app", app,
-					 "review", review2,
-					 NULL);
-	ret = gs_plugin_loader_job_action (plugin_loader, plugin_job, NULL, &error);
-	gs_test_flush_main_context ();
-	g_assert_no_error (error);
-	g_assert (ret);
-}
-
 static void
 gs_plugins_dummy_wildcard_func (GsPluginLoader *plugin_loader)
 {
@@ -734,6 +660,7 @@ gs_plugins_dummy_limit_parallel_ops_func (GsPluginLoader *plugin_loader)
 	g_autoptr(GsDummyTestHelper) helper3 = gs_dummy_test_helper_new ();
 
 	/* drop all caches */
+	g_unlink ("/var/tmp/self-test/appstream/components.xmlb");
 	gs_plugin_loader_setup_again (plugin_loader);
 
 	/* get the updates list */
@@ -825,6 +752,7 @@ gs_plugins_dummy_limit_parallel_ops_func (GsPluginLoader *plugin_loader)
 int
 main (int argc, char **argv)
 {
+	const gchar *tmp_root = "/var/tmp/self-test";
 	gboolean ret;
 	g_autofree gchar *xml = NULL;
 	g_autoptr(GError) error = NULL;
@@ -845,6 +773,7 @@ main (int argc, char **argv)
 
 	g_test_init (&argc, &argv, NULL);
 	g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
+	g_setenv ("GS_XMLB_VERBOSE", "1", TRUE);
 
 	/* set all the things required as a dummy test harness */
 	g_setenv ("GS_SELF_TEST_LOCALE", "en_GB", TRUE);
@@ -853,6 +782,7 @@ main (int argc, char **argv)
 	g_setenv ("GS_SELF_TEST_PROVENANCE_LICENSE_SOURCES", "london*,boston", TRUE);
 	g_setenv ("GS_SELF_TEST_PROVENANCE_LICENSE_URL", "https://www.debian.org/", TRUE);
 	g_setenv ("GNOME_SOFTWARE_POPULAR", "", TRUE);
+	g_setenv ("GS_SELF_TEST_CACHEDIR", tmp_root, TRUE);
 
 	xml = g_strdup ("<?xml version=\"1.0\"?>\n"
 		"<components version=\"0.9\">\n"
@@ -898,6 +828,7 @@ main (int argc, char **argv)
 		"  <component type=\"os-upgrade\">\n"
 		"    <id>org.fedoraproject.release-rawhide.upgrade</id>\n"
 		"    <summary>Release specific tagline</summary>\n"
+		"    <pkgname>fedora-release</pkgname>\n"
 		"  </component>\n"
 		"</components>\n");
 	g_setenv ("GS_SELF_TEST_APPSTREAM_XML", xml, TRUE);
@@ -926,9 +857,6 @@ main (int argc, char **argv)
 	g_test_add_data_func ("/gnome-software/plugins/dummy/wildcard",
 			      plugin_loader,
 			      (GTestDataFunc) gs_plugins_dummy_wildcard_func);
-	g_test_add_data_func ("/gnome-software/plugins/dummy/authentication",
-			      plugin_loader,
-			      (GTestDataFunc) gs_plugins_dummy_authentication_func);
 	g_test_add_data_func ("/gnome-software/plugins/dummy/plugin-cache",
 			      plugin_loader,
 			      (GTestDataFunc) gs_plugins_dummy_plugin_cache_func);
