@@ -109,17 +109,6 @@ _file_changed_cb (GFileMonitor *monitor,
 	GsPlugin *plugin = GS_PLUGIN (user_data);
 	GsPluginData *priv = gs_plugin_get_data (plugin);
 
-	/* only reload the update list if the plugin is NOT running itself
-	 * and the time since it ran is greater than 5 seconds (inotify FTW) */
-	if (gs_plugin_has_flags (plugin, GS_PLUGIN_FLAGS_RUNNING_SELF)) {
-		g_debug ("no notify as plugin %s active", gs_plugin_get_name (plugin));
-		return;
-	}
-	if (gs_plugin_has_flags (plugin, GS_PLUGIN_FLAGS_RECENT)) {
-		g_debug ("no notify as plugin %s recently active", gs_plugin_get_name (plugin));
-		return;
-	}
-
 	g_debug ("cache file changed, so reloading upgrades list");
 	gs_plugin_updates_changed (plugin);
 	priv->is_valid = FALSE;
@@ -220,7 +209,7 @@ _refresh_cache (GsPlugin *plugin,
 				      priv->cachefn,
 				      cancellable,
 				      error)) {
-		gs_utils_error_add_unique_id (error, priv->cached_origin);
+		gs_utils_error_add_origin_id (error, priv->cached_origin);
 		return FALSE;
 	}
 
@@ -310,9 +299,9 @@ _create_upgrade_from_info (GsPlugin *plugin, PkgdbItem *item)
 	gs_app_set_size_installed (app, 1024 * 1024 * 1024); /* estimate */
 	gs_app_set_size_download (app, 256 * 1024 * 1024); /* estimate */
 	gs_app_set_license (app, GS_APP_QUALITY_LOWEST, "LicenseRef-free");
-	gs_app_add_quirk (app, AS_APP_QUIRK_NEEDS_REBOOT);
-	gs_app_add_quirk (app, AS_APP_QUIRK_PROVENANCE);
-	gs_app_add_quirk (app, AS_APP_QUIRK_NOT_REVIEWABLE);
+	gs_app_add_quirk (app, GS_APP_QUIRK_NEEDS_REBOOT);
+	gs_app_add_quirk (app, GS_APP_QUIRK_PROVENANCE);
+	gs_app_add_quirk (app, GS_APP_QUIRK_NOT_REVIEWABLE);
 	gs_app_add_icon (app, ic);
 
 	/* show a Fedora magazine article for the release */
