@@ -265,11 +265,8 @@ gs_plugin_flatpak_get_handler (GsPlugin *plugin, GsApp *app)
 	if (object_id != NULL) {
 		for (guint i = 0; i < priv->flatpaks->len; i++) {
 			GsFlatpak *flatpak = g_ptr_array_index (priv->flatpaks, i);
-			if (g_strcmp0 (gs_flatpak_get_id (flatpak), object_id) == 0) {
-				g_debug ("chose %s using ID",
-					 gs_flatpak_get_id (flatpak));
+			if (g_strcmp0 (gs_flatpak_get_id (flatpak), object_id) == 0)
 				return flatpak;
-			}
 		}
 	}
 
@@ -277,10 +274,8 @@ gs_plugin_flatpak_get_handler (GsPlugin *plugin, GsApp *app)
 	for (guint i = 0; i < priv->flatpaks->len; i++) {
 		GsFlatpak *flatpak = g_ptr_array_index (priv->flatpaks, i);
 		if (_as_app_scope_is_compatible (gs_flatpak_get_scope (flatpak),
-						 gs_app_get_scope (app))) {
-			g_debug ("chose %s using scope", gs_flatpak_get_id (flatpak));
+						 gs_app_get_scope (app)))
 			return flatpak;
-		}
 	}
 	return NULL;
 }
@@ -295,6 +290,12 @@ gs_plugin_flatpak_refine_app (GsPlugin *plugin,
 	GsPluginData *priv = gs_plugin_get_data (plugin);
 	GsFlatpak *flatpak = NULL;
 
+	/* not us */
+	if (gs_app_get_bundle_kind (app) != AS_BUNDLE_KIND_FLATPAK) {
+		g_debug ("%s not a package, ignoring", gs_app_get_unique_id (app));
+		return TRUE;
+	}
+
 	/* we have to look for the app in all GsFlatpak stores */
 	if (gs_app_get_scope (app) == AS_APP_SCOPE_UNKNOWN) {
 		for (guint i = 0; i < priv->flatpaks->len; i++) {
@@ -419,7 +420,6 @@ static FlatpakTransaction *
 _build_transaction (GsPlugin *plugin, GsFlatpak *flatpak,
 		    GCancellable *cancellable, GError **error)
 {
-	GsPluginData *priv = gs_plugin_get_data (plugin);
 	FlatpakInstallation *installation;
 	g_autoptr(FlatpakTransaction) transaction = NULL;
 
@@ -436,14 +436,9 @@ _build_transaction (GsPlugin *plugin, GsFlatpak *flatpak,
 	g_signal_connect (transaction, "ref-to-app",
 			  G_CALLBACK (_ref_to_app), plugin);
 
-	/* add the counterpart installations */
-	for (guint i = 0; i < priv->flatpaks->len; i++) {
-		GsFlatpak *flatpak_tmp = g_ptr_array_index (priv->flatpaks, i);
-		if (flatpak_tmp == flatpak)
-			continue;
-		installation = gs_flatpak_get_installation (flatpak_tmp);
-		flatpak_transaction_add_dependency_source (transaction, installation);
-	}
+	/* use system installations as dependency sources for user installations */
+	flatpak_transaction_add_default_dependency_sources (transaction);
+
 	return g_steal_pointer (&transaction);
 }
 
@@ -521,9 +516,12 @@ gs_plugin_app_remove (GsPlugin *plugin,
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
+
+	/* run transaction */
+	gs_app_set_state (app, AS_APP_STATE_REMOVING);
 	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
-		g_prefix_error (error, "failed to run transaction for %s: ", ref);
 		gs_flatpak_error_convert (error);
+		gs_app_set_state_recover (app);
 		return FALSE;
 	}
 
@@ -657,10 +655,10 @@ gs_plugin_app_install (GsPlugin *plugin,
 	}
 
 	/* run transaction */
+	gs_app_set_state (app, AS_APP_STATE_INSTALLING);
 	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
-		g_prefix_error (error, "failed to run transaction for %s: ",
-				gs_app_get_unique_id (app));
 		gs_flatpak_error_convert (error);
+		gs_app_set_state_recover (app);
 		return FALSE;
 	}
 
@@ -681,17 +679,22 @@ gs_plugin_app_install (GsPlugin *plugin,
 }
 
 gboolean
-gs_plugin_update_app (GsPlugin *plugin,
-		      GsApp *app,
-		      GCancellable *cancellable,
-		      GError **error)
+gs_plugin_update (GsPlugin *plugin,
+                  GsAppList *list,
+                  GCancellable *cancellable,
+                  GError **error)
 {
 	GsFlatpak *flatpak;
 	g_autoptr(FlatpakTransaction) transaction = NULL;
-	g_autofree gchar *ref = NULL;
+	g_autoptr(GsAppList) list_tmp = gs_app_list_new ();
 
 	/* not supported */
-	flatpak = gs_plugin_flatpak_get_handler (plugin, app);
+	for (guint i = 0; i < gs_app_list_length (list); i++) {
+		GsApp *app = gs_app_list_index (list, i);
+		flatpak = gs_plugin_flatpak_get_handler (plugin, app);
+		if (flatpak != NULL)
+			gs_app_list_add (list_tmp, app);
+	}
 	if (flatpak == NULL)
 		return TRUE;
 
@@ -701,14 +704,29 @@ gs_plugin_update_app (GsPlugin *plugin,
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
-	ref = gs_flatpak_app_get_ref_display (app);
-	if (!flatpak_transaction_add_update (transaction, ref, NULL, NULL, error)) {
-		g_prefix_error (error, "failed to add update ref %s: ", ref);
-		gs_flatpak_error_convert (error);
-		return FALSE;
+
+	for (guint i = 0; i < gs_app_list_length (list_tmp); i++) {
+		GsApp *app = gs_app_list_index (list_tmp, i);
+		g_autofree gchar *ref = NULL;
+
+		ref = gs_flatpak_app_get_ref_display (app);
+		if (!flatpak_transaction_add_update (transaction, ref, NULL, NULL, error)) {
+			g_prefix_error (error, "failed to add update ref %s: ", ref);
+			gs_flatpak_error_convert (error);
+			return FALSE;
+		}
+	}
+
+	/* run transaction */
+	for (guint i = 0; i < gs_app_list_length (list_tmp); i++) {
+		GsApp *app = gs_app_list_index (list_tmp, i);
+		gs_app_set_state (app, AS_APP_STATE_INSTALLING);
 	}
 	if (!gs_flatpak_transaction_run (transaction, cancellable, error)) {
-		g_prefix_error (error, "failed to run transaction for %s: ", ref);
+		for (guint i = 0; i < gs_app_list_length (list_tmp); i++) {
+			GsApp *app = gs_app_list_index (list_tmp, i);
+			gs_app_set_state_recover (app);
+		}
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
@@ -719,12 +737,18 @@ gs_plugin_update_app (GsPlugin *plugin,
 		gs_flatpak_error_convert (error);
 		return FALSE;
 	}
-	if (!gs_flatpak_refine_app (flatpak, app,
-				    GS_PLUGIN_REFINE_FLAGS_REQUIRE_RUNTIME,
-				    cancellable, error)) {
-		g_prefix_error (error, "failed to run refine for %s: ", ref);
-		gs_flatpak_error_convert (error);
-		return FALSE;
+	for (guint i = 0; i < gs_app_list_length (list_tmp); i++) {
+		GsApp *app = gs_app_list_index (list_tmp, i);
+		g_autofree gchar *ref = NULL;
+
+		ref = gs_flatpak_app_get_ref_display (app);
+		if (!gs_flatpak_refine_app (flatpak, app,
+					    GS_PLUGIN_REFINE_FLAGS_REQUIRE_RUNTIME,
+					    cancellable, error)) {
+			g_prefix_error (error, "failed to run refine for %s: ", ref);
+			gs_flatpak_error_convert (error);
+			return FALSE;
+		}
 	}
 	return TRUE;
 }
@@ -815,7 +839,7 @@ gs_plugin_flatpak_file_to_app_bundle (GsPlugin *plugin,
 	ref = gs_flatpak_app_get_ref_display (app);
 	app_tmp = gs_plugin_flatpak_find_app_by_ref (plugin, ref, cancellable, NULL);
 	if (app_tmp != NULL)
-		return g_steal_pointer (&app);
+		return g_steal_pointer (&app_tmp);
 
 	/* force this to be 'any' scope for installation */
 	gs_app_set_scope (app, AS_APP_SCOPE_UNKNOWN);
@@ -851,7 +875,7 @@ gs_plugin_flatpak_file_to_app_ref (GsPlugin *plugin,
 	ref = gs_flatpak_app_get_ref_display (app);
 	app_tmp = gs_plugin_flatpak_find_app_by_ref (plugin, ref, cancellable, NULL);
 	if (app_tmp != NULL)
-		return g_steal_pointer (&app);
+		return g_steal_pointer (&app_tmp);
 
 	/* force this to be 'any' scope for installation */
 	gs_app_set_scope (app, AS_APP_SCOPE_UNKNOWN);
