@@ -44,11 +44,17 @@ struct GsPluginData {
 };
 
 static void
-gs_plugin_packagekit_cache_invalid_cb (PkControl *control, GsPlugin *plugin)
+gs_plugin_packagekit_updates_changed_cb (PkControl *control, GsPlugin *plugin)
 {
 	gs_plugin_updates_changed (plugin);
 }
 
+static void
+gs_plugin_packagekit_repo_list_changed_cb (PkControl *control, GsPlugin *plugin)
+{
+	gs_plugin_reload (plugin);
+}
+
 void
 gs_plugin_initialize (GsPlugin *plugin)
 {
@@ -56,9 +62,9 @@ gs_plugin_initialize (GsPlugin *plugin)
 	priv->client = pk_client_new ();
 	priv->control = pk_control_new ();
 	g_signal_connect (priv->control, "updates-changed",
-			  G_CALLBACK (gs_plugin_packagekit_cache_invalid_cb), plugin);
+			  G_CALLBACK (gs_plugin_packagekit_updates_changed_cb), plugin);
 	g_signal_connect (priv->control, "repo-list-changed",
-			  G_CALLBACK (gs_plugin_packagekit_cache_invalid_cb), plugin);
+			  G_CALLBACK (gs_plugin_packagekit_repo_list_changed_cb), plugin);
 	pk_client_set_background (priv->client, FALSE);
 	pk_client_set_cache_age (priv->client, G_MAXUINT);
 
@@ -161,7 +167,7 @@ gs_plugin_packagekit_resolve_packages (GsPlugin *plugin,
                                        GError **error)
 {
 	PkBitfield filter;
-	GsAppList *resolve2_list;
+	g_autoptr(GsAppList) resolve2_list = NULL;
 
 	/* first, try to resolve packages with ARCH filter */
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST,
@@ -415,7 +421,7 @@ gs_plugin_packagekit_refine_update_urgency (GsPlugin *plugin,
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		g_autoptr (PkPackage) pkg = NULL;
 		app = gs_app_list_index (list, i);
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		package_id = gs_app_get_source_id_default (app);
 		if (package_id == NULL)
@@ -480,7 +486,7 @@ gs_plugin_packagekit_refine_details (GsPlugin *plugin,
 	list_tmp = gs_app_list_new ();
 	for (guint i = 0; i < gs_app_list_length (list); i++) {
 		GsApp *app = gs_app_list_index (list, i);
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		if (gs_app_get_kind (app) == AS_APP_KIND_WEB_APP)
 			continue;
@@ -628,7 +634,7 @@ gs_plugin_packagekit_refine_name_to_id (GsPlugin *plugin,
 		GPtrArray *sources;
 		GsApp *app = gs_app_list_index (list, i);
 		const gchar *tmp;
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		if (gs_app_get_kind (app) == AS_APP_KIND_WEB_APP)
 			continue;
@@ -673,7 +679,7 @@ gs_plugin_packagekit_refine_filename_to_id (GsPlugin *plugin,
 		g_autofree gchar *fn = NULL;
 		GsApp *app = gs_app_list_index (list, i);
 		const gchar *tmp;
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		if (gs_app_get_source_id_default (app) != NULL)
 			continue;
@@ -724,7 +730,7 @@ gs_plugin_packagekit_refine_update_details (GsPlugin *plugin,
 	for (guint i = 0; i < gs_app_list_length (list); i++) {
 		GsApp *app = gs_app_list_index (list, i);
 		const gchar *tmp;
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD))
 			continue;
 		if (gs_app_get_state (app) != AS_APP_STATE_UPDATABLE)
 			continue;
