@@ -158,7 +158,7 @@ gs_plugin_add_sources (GsPlugin *plugin,
 		gs_app_set_management_plugin (app, gs_plugin_get_name (plugin));
 		gs_app_set_kind (app, AS_APP_KIND_SOURCE);
 		gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
-		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+		gs_app_add_quirk (app, GS_APP_QUIRK_NOT_LAUNCHABLE);
 		gs_app_set_state (app, pk_repo_detail_get_enabled (rd) ?
 				  AS_APP_STATE_INSTALLED : AS_APP_STATE_AVAILABLE);
 		gs_app_set_name (app,
@@ -197,7 +197,7 @@ gs_plugin_app_origin_repo_enable (GsPlugin *plugin,
 	                                 gs_packagekit_helper_cb, helper,
 	                                 error);
 	if (!gs_plugin_packagekit_results_valid (results, error)) {
-		gs_utils_error_add_unique_id (error, app);
+		gs_utils_error_add_origin_id (error, app);
 		return FALSE;
 	}
 
@@ -230,7 +230,7 @@ gs_plugin_repo_enable (GsPlugin *plugin,
 					 error);
 	if (!gs_plugin_packagekit_results_valid (results, error)) {
 		gs_app_set_state_recover (app);
-		gs_utils_error_add_unique_id (error, app);
+		gs_utils_error_add_origin_id (error, app);
 		return FALSE;
 	}
 
@@ -453,7 +453,7 @@ gs_plugin_repo_disable (GsPlugin *plugin,
 					 error);
 	if (!gs_plugin_packagekit_results_valid (results, error)) {
 		gs_app_set_state_recover (app);
-		gs_utils_error_add_unique_id (error, app);
+		gs_utils_error_add_origin_id (error, app);
 		return FALSE;
 	}
 
