@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2016-2018 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2018 Kalev Lember <klember@redhat.com>
  *
  * Licensed under the GNU General Public License Version 2
@@ -24,11 +24,13 @@
 
 #include <errno.h>
 #include <glib/gi18n.h>
-#include <glib/gstdio.h>
 #include <json-glib/json-glib.h>
+#include <xmlb.h>
 
 #include <gnome-software.h>
 
+#include "gs-appstream.h"
+
 #define SHELL_EXTENSIONS_API_URI 		"https://extensions.gnome.org/"
 
 /*
@@ -47,6 +49,7 @@ struct GsPluginData {
 	gchar		*shell_version;
 	GsApp		*cached_origin;
 	GSettings	*settings;
+	XbSilo		*silo;
 };
 
 typedef enum {
@@ -66,6 +69,8 @@ typedef enum {
 	GS_PLUGIN_SHELL_EXTENSION_KIND_LAST
 } GsPluginShellExtensionKind;
 
+static gboolean _check_silo (GsPlugin *plugin, GCancellable *cancellable, GError **error);
+
 void
 gs_plugin_initialize (GsPlugin *plugin)
 {
@@ -92,6 +97,8 @@ gs_plugin_destroy (GsPlugin *plugin)
 	g_free (priv->shell_version);
 	if (priv->proxy != NULL)
 		g_object_unref (priv->proxy);
+	if (priv->silo != NULL)
+		g_object_unref (priv->silo);
 	g_object_unref (priv->cached_origin);
 	g_object_unref (priv->settings);
 }
@@ -393,7 +400,7 @@ gs_plugin_add_sources (GsPlugin *plugin,
 		gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 	else
 		gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
-	gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+	gs_app_add_quirk (app, GS_APP_QUIRK_NOT_LAUNCHABLE);
 	gs_app_set_name (app, GS_APP_QUALITY_LOWEST,
 	                 _("GNOME Shell Extensions Repository"));
 	gs_app_set_url (app, AS_URL_KIND_HOMEPAGE,
@@ -410,7 +417,15 @@ gs_plugin_refine_app (GsPlugin *plugin,
 		      GCancellable *cancellable,
 		      GError **error)
 {
+	GsPluginData *priv = gs_plugin_get_data (plugin);
 	const gchar *uuid;
+	g_autofree gchar *xpath = NULL;
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(XbNode) component = NULL;
+
+	/* repo not enabled */
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
 
 	/* only process this app if was created by this plugin */
 	if (g_strcmp0 (gs_app_get_management_plugin (app),
@@ -438,12 +453,84 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	if (gs_app_get_size_download (app) == 0)
 		gs_app_set_size_download (app, GS_APP_SIZE_UNKNOWABLE);
 
+
+	/* find the component using the UUID */
+	if (!_check_silo (plugin, cancellable, error))
+		return FALSE;
+	xpath = g_strdup_printf ("components/component/custom/"
+				 "value[@key='shell-extensions::uuid'][text()='%s']/../..",
+				 uuid);
+	component = xb_silo_query_first (priv->silo, xpath, &error_local);
+	if (component == NULL) {
+		if (g_error_matches (error_local, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+			return TRUE;
+		if (g_error_matches (error_local, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT))
+			return TRUE;
+		g_propagate_error (error, g_steal_pointer (&error_local));
+		return FALSE;
+	}
+	return gs_appstream_refine_app (plugin, app, priv->silo, component, flags, error);
+}
+
+gboolean
+gs_plugin_refine_wildcard (GsPlugin *plugin,
+			   GsApp *app,
+			   GsAppList *list,
+			   GsPluginRefineFlags refine_flags,
+			   GCancellable *cancellable,
+			   GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	const gchar *id;
+	g_autofree gchar *xpath = NULL;
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(GPtrArray) components = NULL;
+
+	/* repo not enabled */
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
+
+	/* check silo is valid */
+	if (!_check_silo (plugin, cancellable, error))
+		return FALSE;
+
+	/* not enough info to find */
+	id = gs_app_get_id (app);
+	if (id == NULL)
+		return TRUE;
+
+	/* find all apps */
+	xpath = g_strdup_printf ("components/component/id[text()='%s']/..", id);
+	components = xb_silo_query (priv->silo, xpath, 0, &error_local);
+	if (components == NULL) {
+		if (g_error_matches (error_local, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+			return TRUE;
+		if (g_error_matches (error_local, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT))
+			return TRUE;
+		g_propagate_error (error, g_steal_pointer (&error_local));
+		return FALSE;
+	}
+	for (guint i = 0; i < components->len; i++) {
+		XbNode *component = g_ptr_array_index (components, i);
+		g_autoptr(GsApp) new = NULL;
+		new = gs_appstream_create_app (plugin, priv->silo, component, error);
+		if (new == NULL)
+			return FALSE;
+		gs_app_subsume_metadata (new, app);
+		if (!gs_appstream_refine_app (plugin, new, priv->silo, component,
+					      refine_flags, error))
+			return FALSE;
+		gs_app_list_add (list, new);
+	}
+
+	/* success */
 	return TRUE;
 }
 
 static gboolean
 gs_plugin_shell_extensions_parse_version (GsPlugin *plugin,
-					  AsApp *app,
+					  const gchar *component_id,
+					  XbBuilderNode *app,
 					  JsonObject *ver_map,
 					  GError **error)
 {
@@ -451,7 +538,7 @@ gs_plugin_shell_extensions_parse_version (GsPlugin *plugin,
 	JsonObject *json_ver = NULL;
 	gint64 version;
 	g_autofree gchar *shell_version = NULL;
-	g_autoptr(AsRelease) release = NULL;
+	g_autoptr(XbBuilderNode) release = NULL;
 
 	/* look for version, major.minor.micro */
 	if (json_object_has_member (ver_map, priv->shell_version)) {
@@ -472,12 +559,8 @@ gs_plugin_shell_extensions_parse_version (GsPlugin *plugin,
 	}
 
 	/* FIXME: mark as incompatible? */
-	if (json_ver == NULL) {
-		g_debug ("no version_map for %s: %s",
-			 as_app_get_id (app),
-			 priv->shell_version);
+	if (json_ver == NULL)
 		return TRUE;
-	}
 
 	/* parse the version */
 	version = json_object_get_int_member (json_ver, "version");
@@ -491,121 +574,119 @@ gs_plugin_shell_extensions_parse_version (GsPlugin *plugin,
 	shell_version = g_strdup_printf ("%" G_GINT64_FORMAT, version);
 
 	/* add a dummy release */
-	release = as_release_new ();
-	as_release_set_version (release, shell_version);
-	as_app_add_release (app, release);
+	xb_builder_node_insert_text (app, "release", NULL,
+				     "version", shell_version,
+				     NULL);
 	return TRUE;
 }
 
-static AsApp *
+
+
+static XbBuilderNode *
 gs_plugin_shell_extensions_parse_app (GsPlugin *plugin,
 				      JsonObject *json_app,
 				      GError **error)
 {
-	g_autoptr(AsApp) app = NULL;
 	JsonObject *json_ver_map;
 	const gchar *tmp;
+	g_autofree gchar *component_id = NULL;
+	g_autoptr(XbBuilderNode) app = NULL;
+	g_autoptr(XbBuilderNode) categories = NULL;
+	g_autoptr(XbBuilderNode) metadata = NULL;
 
-	app = as_app_new ();
-	as_app_set_kind (app, AS_APP_KIND_SHELL_EXTENSION);
-	as_app_set_project_license (app, "GPL-2.0+");
+	app = xb_builder_node_new ("component");
+	xb_builder_node_set_attr (app, "kind", "shell-extension");
+	xb_builder_node_insert_text (app, "project_license", "GPL-2.0+", NULL);
+	categories = xb_builder_node_insert (app, "categories", NULL);
+	xb_builder_node_insert_text (categories, "category", "Addon", NULL);
+	xb_builder_node_insert_text (categories, "category", "ShellExtension", NULL);
+	metadata = xb_builder_node_insert (app, "custom", NULL);
 
 	tmp = json_object_get_string_member (json_app, "description");
 	if (tmp != NULL) {
-		g_autofree gchar *desc = NULL;
-		desc = as_markup_import (tmp, AS_MARKUP_CONVERT_FORMAT_SIMPLE, error);
-		if (desc == NULL) {
-			gs_utils_error_convert_appstream (error);
-			return NULL;
-		}
-		as_app_set_description (app, NULL, desc);
+		g_auto(GStrv) paras = g_strsplit (tmp, "\n", -1);
+		g_autoptr(XbBuilderNode) desc = xb_builder_node_insert (app, "description", NULL);
+		for (guint i = 0; paras[i] != NULL; i++)
+			xb_builder_node_insert_text (desc, "p", paras[i], NULL);
 	}
 	tmp = json_object_get_string_member (json_app, "screenshot");
 	if (tmp != NULL) {
-		g_autoptr(AsScreenshot) ss = NULL;
-		g_autoptr(AsImage) im = NULL;
+		g_autoptr(XbBuilderNode) screenshots = NULL;
+		g_autoptr(XbBuilderNode) screenshot = NULL;
 		g_autofree gchar *uri = NULL;
+		screenshots = xb_builder_node_insert (app, "screenshots", NULL);
+		screenshot = xb_builder_node_insert (screenshots, "screenshot",
+						     "kind", "default",
+						     NULL);
 		uri = g_build_path ("/", SHELL_EXTENSIONS_API_URI, tmp, NULL);
-		im = as_image_new ();
-		as_image_set_kind (im, AS_IMAGE_KIND_SOURCE);
-		as_image_set_url (im, uri);
-		ss = as_screenshot_new ();
-		as_screenshot_set_kind (ss, AS_SCREENSHOT_KIND_DEFAULT);
-		as_screenshot_add_image (ss, im);
-		as_app_add_screenshot (app, ss);
+		xb_builder_node_insert_text (screenshot, "image", uri,
+					     "kind", "source",
+					     NULL);
 	}
 	tmp = json_object_get_string_member (json_app, "name");
 	if (tmp != NULL)
-		as_app_set_name (app, NULL, tmp);
+		xb_builder_node_insert_text (app, "name", tmp, NULL);
 	tmp = json_object_get_string_member (json_app, "uuid");
 	if (tmp != NULL) {
-		g_autofree gchar *id = NULL;
-		id = as_utils_appstream_id_build (tmp);
-		as_app_set_id (app, id);
-		as_app_add_metadata (app, "shell-extensions::uuid", tmp);
+		component_id = as_utils_appstream_id_build (tmp);
+		xb_builder_node_insert_text (app, "id", component_id, NULL);
+		xb_builder_node_insert_text (metadata, "value", tmp,
+					     "key", "shell-extensions::uuid",
+					     NULL);
 	}
 	tmp = json_object_get_string_member (json_app, "link");
 	if (tmp != NULL) {
 		g_autofree gchar *uri = NULL;
 		uri = g_build_filename (SHELL_EXTENSIONS_API_URI, tmp, NULL);
-		as_app_add_url (app, AS_URL_KIND_HOMEPAGE, uri);
+		xb_builder_node_insert_text (app, "url", uri,
+					     "type", "homepage",
+					     NULL);
 	}
 	tmp = json_object_get_string_member (json_app, "icon");
 	if (tmp != NULL) {
-		g_autoptr(AsIcon) ic = NULL;
 		/* just use a stock icon as the remote icons are
 		 * sometimes missing, poor quality and low resolution */
-		ic = as_icon_new ();
-		as_icon_set_kind (ic, AS_ICON_KIND_STOCK);
-		as_icon_set_name (ic, "application-x-addon-symbolic");
-		as_app_add_icon (app, ic);
+		xb_builder_node_insert_text (app, "icon",
+					     "application-x-addon-symbolic",
+					     "type", "stock",
+					     NULL);
 	}
 
 	/* try to get version */
 	json_ver_map = json_object_get_object_member (json_app, "shell_version_map");
 	if (json_ver_map != NULL) {
 		if (!gs_plugin_shell_extensions_parse_version (plugin,
+							       component_id,
 							       app,
 							       json_ver_map,
 							       error))
 			return NULL;
 	}
 
-	/* we have no data :/ */
-	as_app_add_metadata (app, "GnomeSoftware::Plugin",
-			     gs_plugin_get_name (plugin));
-	as_app_add_metadata (app, "GnomeSoftware::OriginHostnameUrl",
-			     SHELL_EXTENSIONS_API_URI);
-
 	return g_steal_pointer (&app);
 }
 
-static GPtrArray *
-gs_plugin_shell_extensions_parse_apps (GsPlugin *plugin,
-				       const gchar *data,
-				       gssize data_len,
-				       GError **error)
+static GInputStream *
+gs_plugin_appstream_load_json_cb (XbBuilderSource *self,
+				  GFile *file,
+				  gpointer user_data,
+				  GCancellable *cancellable,
+				  GError **error)
 {
-	GPtrArray *apps;
+	GsPlugin *plugin = GS_PLUGIN (user_data);
 	JsonArray *json_extensions_array;
 	JsonNode *json_extensions;
 	JsonNode *json_root;
 	JsonObject *json_item;
-	guint i;
+	gchar *xml;
+	g_autofree gchar *fn = g_file_get_path (file);
+	g_autoptr(AsApp) app = as_app_new ();
 	g_autoptr(JsonParser) json_parser = NULL;
-
-	/* nothing */
-	if (data == NULL) {
-		g_set_error_literal (error,
-				     GS_PLUGIN_ERROR,
-				     GS_PLUGIN_ERROR_INVALID_FORMAT,
-				     "server returned no data");
-		return NULL;
-	}
+	g_autoptr(XbBuilderNode) apps = NULL;
 
 	/* parse the data and find the success */
 	json_parser = json_parser_new ();
-	if (!json_parser_load_from_data (json_parser, data, data_len, error)) {
+	if (!json_parser_load_from_file (json_parser, fn, error)) {
 		gs_utils_error_convert_json_glib (error);
 		return NULL;
 	}
@@ -634,7 +715,7 @@ gs_plugin_shell_extensions_parse_apps (GsPlugin *plugin,
 	}
 
 	/* load extensions */
-	apps = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	apps = xb_builder_node_new ("components");
 	json_extensions = json_object_get_member (json_item, "extensions");
 	if (json_extensions == NULL) {
 		g_set_error_literal (error,
@@ -653,90 +734,25 @@ gs_plugin_shell_extensions_parse_apps (GsPlugin *plugin,
 	}
 
 	/* parse each app */
-	for (i = 0; i < json_array_get_length (json_extensions_array); i++) {
-		AsApp *app;
+	for (guint i = 0; i < json_array_get_length (json_extensions_array); i++) {
+		XbBuilderNode *component;
 		JsonNode *json_extension;
 		JsonObject *json_extension_obj;
 		json_extension = json_array_get_element (json_extensions_array, i);
 		json_extension_obj = json_node_get_object (json_extension);
-		app = gs_plugin_shell_extensions_parse_app (plugin,
+		component = gs_plugin_shell_extensions_parse_app (plugin,
 							    json_extension_obj,
 							    error);
-		if (app == NULL)
+		if (component == NULL)
 			return NULL;
-		g_ptr_array_add (apps, app);
+		xb_builder_node_add_child (apps, component);
 	}
 
-	return apps;
-}
-
-static GPtrArray *
-gs_plugin_shell_extensions_get_apps (GsPlugin *plugin,
-				     guint cache_age,
-				     GCancellable *cancellable,
-				     GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-	GPtrArray *apps;
-	g_autofree gchar *cachefn = NULL;
-	g_autofree gchar *uri = NULL;
-	g_autoptr(GFile) cachefn_file = NULL;
-	g_autoptr(GBytes) data = NULL;
-	g_autoptr(GsApp) app_dl = gs_app_new (gs_plugin_get_name (plugin));
-
-	/* look in the cache */
-	cachefn = gs_utils_get_cache_filename ("shell-extensions",
-					       "gnome.json",
-					       GS_UTILS_CACHE_FLAG_WRITEABLE,
-					       error);
-	if (cachefn == NULL)
+	/* convert back to XML */
+	xml = xb_builder_node_export (apps, XB_NODE_EXPORT_FLAG_NONE, error);
+	if (xml == NULL)
 		return NULL;
-	cachefn_file = g_file_new_for_path (cachefn);
-	if (gs_utils_get_file_age (cachefn_file) < cache_age) {
-		g_autofree gchar *json_data = NULL;
-		if (!g_file_get_contents (cachefn, &json_data, NULL, error))
-			return NULL;
-		g_debug ("got cached extension data from %s", cachefn);
-		return gs_plugin_shell_extensions_parse_apps (plugin,
-							      json_data,
-							      -1, error);
-	}
-
-	/* create the GET data */
-	uri = g_strdup_printf ("%s/static/extensions.json",
-			       SHELL_EXTENSIONS_API_URI);
-	gs_app_set_summary_missing (app_dl,
-				    /* TRANSLATORS: status text when downloading */
-				    _("Downloading shell extension metadata…"));
-	data = gs_plugin_download_data (plugin, app_dl, uri, cancellable, error);
-	if (data == NULL) {
-		gs_utils_error_add_origin_id (error, priv->cached_origin);
-		return NULL;
-	}
-	apps = gs_plugin_shell_extensions_parse_apps (plugin,
-						      g_bytes_get_data (data, NULL),
-						      (gssize) g_bytes_get_size (data),
-						      error);
-	if (apps == NULL) {
-		gsize len = g_bytes_get_size (data);
-		g_autofree gchar *tmp = NULL;
-
-		/* truncate the string if long */
-		if (len > 100)
-			len = 100;
-		tmp = g_strndup (g_bytes_get_data (data, NULL), len);
-		g_prefix_error (error, "Failed to parse '%s': ", tmp);
-		return NULL;
-	}
-
-	/* save to the cache */
-	if (!g_file_set_contents (cachefn,
-				  g_bytes_get_data (data, NULL),
-				  (guint) g_bytes_get_size (data),
-				  error))
-		return NULL;
-
-	return apps;
+	return g_memory_input_stream_new_from_data (xml, -1, g_free);
 }
 
 static gboolean
@@ -746,34 +762,20 @@ gs_plugin_shell_extensions_refresh (GsPlugin *plugin,
 				    GError **error)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
-	AsApp *app;
-	gboolean repo_enabled;
-	const gchar *fn_test;
-	guint i;
 	g_autofree gchar *fn = NULL;
-	g_autoptr(GPtrArray) apps = NULL;
-	g_autoptr(AsStore) store = NULL;
+	g_autofree gchar *uri = NULL;
 	g_autoptr(GFile) file = NULL;
+	g_autoptr(GsApp) app_dl = gs_app_new (gs_plugin_get_name (plugin));
+
+	/* get cache filename */
+	fn = gs_utils_get_cache_filename ("shell-extensions",
+					  "gnome.json",
+					  GS_UTILS_CACHE_FLAG_WRITEABLE,
+					  error);
+	if (fn == NULL)
+		return FALSE;
 
 	/* check age */
-	fn_test = g_getenv ("GS_SELF_TEST_SHELL_EXTENSIONS_XML_FN");
-	if (fn_test != NULL) {
-		fn = g_strdup (fn_test);
-	} else {
-		fn = g_build_filename (g_get_user_data_dir (),
-				       "app-info",
-				       "xmls",
-				       "extensions-web.xml",
-				       NULL);
-	}
-
-	/* remove old appstream data if the repo is disabled */
-	repo_enabled = g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo");
-	if (!repo_enabled) {
-		g_unlink (fn);
-		return TRUE;
-	}
-
 	file = g_file_new_for_path (fn);
 	if (g_file_query_exists (file, NULL)) {
 		guint age = gs_utils_get_file_age (file);
@@ -783,33 +785,143 @@ gs_plugin_shell_extensions_refresh (GsPlugin *plugin,
 		}
 	}
 
-	/* get data */
-	apps = gs_plugin_shell_extensions_get_apps (plugin,
-						    cache_age,
-						    cancellable,
-						    error);
-	if (apps == NULL)
+	/* download the file */
+	uri = g_strdup_printf ("%s/static/extensions.json",
+			       SHELL_EXTENSIONS_API_URI);
+	gs_app_set_summary_missing (app_dl,
+				    /* TRANSLATORS: status text when downloading */
+				    _("Downloading shell extension metadata…"));
+	if (!gs_plugin_download_file (plugin, app_dl, uri, fn, cancellable, error)) {
+		gs_utils_error_add_origin_id (error, priv->cached_origin);
 		return FALSE;
-
-	/* add to local store */
-	store = as_store_new ();
-	as_store_set_origin (store, "extensions-web");
-	for (i = 0; i < apps->len; i++) {
-		app = g_ptr_array_index (apps, i);
-		g_debug ("adding to local store %s", as_app_get_id (app));
-		as_store_add_app (store, app);
 	}
 
-	/* save to disk */
-	if (!gs_mkdir_parent (fn, error))
+	/* be explicit */
+	if (priv->silo != NULL)
+		xb_silo_invalidate (priv->silo);
+	return TRUE;
+}
+
+static gboolean
+_check_silo (GsPlugin *plugin, GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autofree gchar *blobfn = NULL;
+	g_autofree gchar *fn = NULL;
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(GFile) blobfile = NULL;
+	g_autoptr(GFile) file = NULL;
+	g_autoptr(XbBuilder) builder = xb_builder_new ();
+	g_autoptr(XbBuilderSource) source = xb_builder_source_new ();
+
+	/* everything is okay */
+	if (priv->silo != NULL && xb_silo_is_valid (priv->silo)) {
+		g_debug ("silo already valid");
+		return TRUE;
+	}
+
+	/* drat! silo needs regenerating */
+	g_clear_object (&priv->silo);
+
+	/* verbose profiling */
+	if (g_getenv ("GS_XMLB_VERBOSE") != NULL) {
+		xb_builder_set_profile_flags (builder,
+					      XB_SILO_PROFILE_FLAG_XPATH |
+					      XB_SILO_PROFILE_FLAG_DEBUG);
+	}
+
+	/* add support for JSON files */
+	fn = gs_utils_get_cache_filename ("shell-extensions",
+					  "gnome.json",
+					  GS_UTILS_CACHE_FLAG_WRITEABLE,
+					  error);
+	if (fn == NULL)
 		return FALSE;
-	g_debug ("saving to %s", fn);
-	return as_store_to_file (store, file,
-				 AS_NODE_TO_XML_FLAG_ADD_HEADER |
-				 AS_NODE_TO_XML_FLAG_FORMAT_INDENT |
-				 AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE,
-				 cancellable,
-				 error);
+	xb_builder_source_add_converter (source,
+					 "application/json",
+					 gs_plugin_appstream_load_json_cb,
+					 plugin, NULL);
+	file = g_file_new_for_path (fn);
+	if (!xb_builder_source_load_file (source, file,
+					  XB_BUILDER_SOURCE_FLAG_WATCH_FILE,
+					  cancellable,
+					  error)) {
+		return FALSE;
+	}
+	xb_builder_import_source (builder, source);
+
+	/* create binary cache */
+	blobfn = gs_utils_get_cache_filename ("shell-extensions",
+					      "extensions-web.xmlb",
+					      GS_UTILS_CACHE_FLAG_WRITEABLE,
+					      error);
+	if (blobfn == NULL)
+		return FALSE;
+	blobfile = g_file_new_for_path (blobfn);
+	g_debug ("ensuring %s", blobfn);
+	priv->silo = xb_builder_ensure (builder, blobfile,
+					XB_BUILDER_COMPILE_FLAG_IGNORE_INVALID,
+					NULL, &error_local);
+	if (priv->silo == NULL) {
+		g_set_error (error,
+			     GS_PLUGIN_ERROR,
+			     GS_PLUGIN_ERROR_FAILED,
+			     "failed to compile %s",
+			     error_local->message);
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
+static void
+_claim_components (GsPlugin *plugin, GsAppList *list)
+{
+	for (guint i = 0; i < gs_app_list_length (list); i++) {
+		GsApp *app = gs_app_list_index (list, i);
+		gs_app_set_kind (app, AS_APP_KIND_SHELL_EXTENSION);
+		gs_app_set_management_plugin (app, gs_plugin_get_name (plugin));
+		gs_app_set_summary (app, GS_APP_QUALITY_LOWEST,
+				    /* TRANSLATORS: the one-line summary */
+				    _("GNOME Shell Extension"));
+	}
+}
+
+gboolean
+gs_plugin_add_search (GsPlugin *plugin, gchar **values, GsAppList *list,
+		      GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autoptr(GsAppList) list_tmp = gs_app_list_new ();
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
+	if (!_check_silo (plugin, cancellable, error))
+		return FALSE;
+	if (!gs_appstream_search (plugin, priv->silo, values, list_tmp,
+				  cancellable, error))
+		return FALSE;
+	_claim_components (plugin, list_tmp);
+	gs_app_list_add_list (list, list_tmp);
+	return TRUE;
+}
+
+gboolean
+gs_plugin_add_category_apps (GsPlugin *plugin, GsCategory *category, GsAppList *list,
+			     GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autoptr(GsAppList) list_tmp = gs_app_list_new ();
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
+	if (!_check_silo (plugin, cancellable, error))
+		return FALSE;
+	if (!gs_appstream_add_category_apps (plugin, priv->silo, category,
+					     list_tmp, cancellable, error))
+		return FALSE;
+	_claim_components (plugin, list_tmp);
+	gs_app_list_add_list (list, list_tmp);
+	return TRUE;
 }
 
 gboolean
@@ -818,10 +930,15 @@ gs_plugin_refresh (GsPlugin *plugin,
 		   GCancellable *cancellable,
 		   GError **error)
 {
-	return gs_plugin_shell_extensions_refresh (plugin,
-						   cache_age,
-						   cancellable,
-						   error);
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
+	if (!gs_plugin_shell_extensions_refresh (plugin,
+						 cache_age,
+						 cancellable,
+						 error))
+		return FALSE;
+	return _check_silo (plugin, cancellable, error);
 }
 
 gboolean
@@ -1002,6 +1119,12 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			  GCancellable *cancellable,
 			  GError **error)
 {
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+
+	/* repo not enabled */
+	if (!g_settings_get_boolean (priv->settings, "enable-shell-extensions-repo"))
+		return TRUE;
+
 	/* just ensure there is any data, no matter how old */
 	return gs_plugin_shell_extensions_refresh (plugin,
 						   G_MAXUINT,
