@@ -22,6 +22,7 @@
 #include "config.h"
 
 #include <glib/gstdio.h>
+#include <xmlb.h>
 
 #include "gnome-software-private.h"
 
@@ -77,12 +78,14 @@ gs_plugins_shell_extensions_installed_func (GsPluginLoader *plugin_loader)
 static void
 gs_plugins_shell_extensions_remote_func (GsPluginLoader *plugin_loader)
 {
-	const gchar *xml_fn = "/var/tmp/self-test/extensions-web.xml";
+	const gchar *cachedir = "/var/tmp/gs-self-test";
 	gboolean ret;
+	g_autofree gchar *fn = NULL;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GFile) file = NULL;
+	g_autoptr(GPtrArray) components = NULL;
 	g_autoptr(GsPluginJob) plugin_job = NULL;
-	g_autoptr(AsStore) store = NULL;
+	g_autoptr(XbSilo) silo = NULL;
 
 	/* no shell-extensions, abort */
 	if (!gs_plugin_loader_get_enabled (plugin_loader, "shell-extensions")) {
@@ -91,10 +94,10 @@ gs_plugins_shell_extensions_remote_func (GsPluginLoader *plugin_loader)
 	}
 
 	/* ensure files are removed */
-	g_unlink (xml_fn);
+	g_setenv ("GS_SELF_TEST_CACHEDIR", cachedir, TRUE);
+	gs_utils_rmtree (cachedir, NULL);
 
 	/* refresh the metadata */
-	g_setenv ("GS_SELF_TEST_SHELL_EXTENSIONS_XML_FN", xml_fn, TRUE);
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFRESH,
 					 "age", (guint64) G_MAXUINT,
 					 NULL);
@@ -103,12 +106,23 @@ gs_plugins_shell_extensions_remote_func (GsPluginLoader *plugin_loader)
 	g_assert (ret);
 
 	/* ensure file was populated */
-	store = as_store_new ();
-	file = g_file_new_for_path (xml_fn);
-	ret = as_store_from_file (store, file, NULL, NULL, &error);
+	silo = xb_silo_new ();
+	fn = gs_utils_get_cache_filename ("shell-extensions",
+					  "extensions-web.xmlb",
+					  GS_UTILS_CACHE_FLAG_WRITEABLE,
+					  &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (fn);
+	file = g_file_new_for_path (fn);
+	ret = xb_silo_load_from_file (silo, file,
+				      XB_SILO_LOAD_FLAG_NONE,
+				      NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
-	g_assert_cmpint (as_store_get_size (store), >, 20);
+	components = xb_silo_query (silo, "components/component", 0, &error);
+	g_assert_no_error (error);
+	g_assert_nonnull (components);
+	g_assert_cmpint (components->len, >, 20);
 }
 
 int
