@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2015-2016 Canonical Ltd
+ * Copyright (C) 2015-2018 Canonical Ltd
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -54,6 +54,9 @@ get_client (GsPlugin *plugin, GError **error)
 	return g_steal_pointer (&client);
 }
 
+static void
+load_auth (GsPlugin *plugin);
+
 void
 gs_plugin_initialize (GsPlugin *plugin)
 {
@@ -72,13 +75,21 @@ gs_plugin_initialize (GsPlugin *plugin)
 	priv->store_snaps = g_hash_table_new_full (g_str_hash, g_str_equal,
 						   g_free, (GDestroyNotify) g_object_unref);
 
-	priv->auth = gs_auth_new ("snapd");
-	gs_auth_set_provider_name (priv->auth, "Snap Store");
-	gs_auth_set_provider_schema (priv->auth, "com.ubuntu.SnapStore.GnomeSoftware");
-	gs_plugin_add_auth (plugin, priv->auth);
+	priv->auth = gs_auth_new ("snapd", "ubuntusso", &error);
+	if (priv->auth) {
+		gs_auth_set_provider_name (priv->auth, "Snap Store");
+		gs_auth_set_header (priv->auth, _("To continue, you need to use an Ubuntu One account."),
+						_("To continue, you need to use your Ubuntu One account."),
+						_("To continue, you need to use an Ubuntu One account."));
+		gs_plugin_add_auth (plugin, priv->auth);
+		g_signal_connect_object (priv->auth, "changed",
+					 G_CALLBACK (load_auth),
+					 plugin, G_CONNECT_SWAPPED);
+	} else {
+		g_warning ("Failed to instantiate the snapd authentication object: %s", error->message);
+	}
 
 	gs_plugin_add_rule (plugin, GS_PLUGIN_RULE_RUN_AFTER, "desktop-categories");
-	gs_plugin_add_rule (plugin, GS_PLUGIN_RULE_RUN_AFTER, "ubuntu-reviews");
 	gs_plugin_add_rule (plugin, GS_PLUGIN_RULE_BETTER_THAN, "packagekit");
 	gs_plugin_add_rule (plugin, GS_PLUGIN_RULE_RUN_BEFORE, "icons");
 
@@ -117,9 +128,6 @@ snapd_error_convert (GError **perror)
 			g_free (error->message);
 			error->message = g_strdup ("Requires authentication with @snapd");
 			break;
-		case SNAPD_ERROR_TWO_FACTOR_REQUIRED:
-			error->code = GS_PLUGIN_ERROR_PIN_REQUIRED;
-			break;
 		case SNAPD_ERROR_AUTH_DATA_INVALID:
 		case SNAPD_ERROR_TWO_FACTOR_INVALID:
 			error->code = GS_PLUGIN_ERROR_AUTH_INVALID;
@@ -161,32 +169,53 @@ load_auth (GsPlugin *plugin)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
 	GsAuth *auth;
-	const gchar *serialized_macaroon;
-	g_autoptr(GVariant) macaroon_variant = NULL;
-	const gchar *macaroon;
-	g_auto(GStrv) discharges = NULL;
+	GoaObject *goa_object;
+	GoaPasswordBased *password_based;
+	g_autofree gchar *macaroon = NULL;
+	g_autofree gchar *discharges_str = NULL;
+	g_autoptr(GVariant) discharges_var = NULL;
+	g_autofree const gchar **discharges = NULL;
 	g_autoptr(SnapdAuthData) auth_data = NULL;
+	g_autoptr(GError) error = NULL;
 
 	auth = gs_plugin_get_auth_by_id (plugin, "snapd");
 	if (auth == NULL)
 		return;
 
-	serialized_macaroon = gs_auth_get_metadata_item (auth, "macaroon");
-	if (serialized_macaroon == NULL)
-		return;
-
-	macaroon_variant = g_variant_parse (G_VARIANT_TYPE ("(sas)"),
-					    serialized_macaroon,
-					    NULL,
-					    NULL,
-					    NULL);
-	if (macaroon_variant == NULL)
-		return;
-
-	g_variant_get (macaroon_variant, "(&s^as)", &macaroon, &discharges);
 	g_clear_object (&priv->auth_data);
+	goa_object = gs_auth_peek_goa_object (auth);
+	if (goa_object == NULL)
+		return;
+
+	password_based = goa_object_peek_password_based (goa_object);
+	g_return_if_fail (password_based != NULL);
+
+	goa_password_based_call_get_password_sync (password_based,
+						   "macaroon",
+						   &macaroon,
+						   NULL, &error);
+	if (error != NULL) {
+		g_warning ("Failed to get macaroon: %s", error->message);
+		return;
+	}
+
+	goa_password_based_call_get_password_sync (password_based,
+						   "discharges",
+						   &discharges_str,
+						   NULL, &error);
+	if (error != NULL) {
+		g_warning ("Failed to get discharges %s", error->message);
+		return;
+	}
+
+	if (discharges_str)
+		discharges_var = g_variant_parse (G_VARIANT_TYPE ("as"),
+						  discharges_str,
+						  NULL, NULL, NULL);
+	if (discharges_var)
+		discharges = g_variant_get_strv (discharges_var, NULL);
+
 	priv->auth_data = snapd_auth_data_new (macaroon, discharges);
-	gs_auth_add_flags (priv->auth, GS_AUTH_FLAG_VALID);
 }
 
 gboolean
@@ -209,15 +238,6 @@ gs_plugin_setup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 					     _("Snap Store"));
 	priv->system_confinement = snapd_system_information_get_confinement (system_information);
 
-	/* load from disk */
-	gs_auth_add_metadata (priv->auth, "macaroon", NULL);
-	if (!gs_auth_store_load (priv->auth,
-				 GS_AUTH_STORE_FLAG_USERNAME |
-				 GS_AUTH_STORE_FLAG_METADATA,
-				 cancellable, error))
-		return FALSE;
-	load_auth (plugin);
-
 	/* success */
 	return TRUE;
 }
@@ -313,9 +333,9 @@ snap_to_app (GsPlugin *plugin, SnapdSnap *snap)
 
 	gs_app_set_management_plugin (app, "snap");
 	if (gs_app_get_kind (app) != AS_APP_KIND_DESKTOP)
-		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+		gs_app_add_quirk (app, GS_APP_QUIRK_NOT_LAUNCHABLE);
 	if (gs_plugin_check_distro_id (plugin, "ubuntu"))
-		gs_app_add_quirk (app, AS_APP_QUIRK_PROVENANCE);
+		gs_app_add_quirk (app, GS_APP_QUIRK_PROVENANCE);
 
 	confinement = snapd_snap_get_confinement (snap);
 	if (confinement != SNAPD_CONFINEMENT_UNKNOWN) {
@@ -349,7 +369,7 @@ gs_plugin_url_to_app (GsPlugin *plugin,
 
 	/* create app */
 	path = gs_utils_get_url_path (url);
-	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_MATCH_NAME, NULL, path, cancellable, NULL);
+	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE | SNAPD_FIND_FLAGS_MATCH_NAME, NULL, path, cancellable, NULL);
 	if (snaps == NULL || snaps->len < 1)
 		return TRUE;
 
@@ -406,7 +426,7 @@ gs_plugin_add_featured (GsPlugin *plugin,
 	g_autoptr(GString) background_css = NULL;
 	g_autofree gchar *css = NULL;
 
-	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_NONE, "featured", NULL, cancellable, error);
+	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE, "featured", NULL, cancellable, error);
 
 	if (snaps == NULL)
 		return FALSE;
@@ -473,7 +493,7 @@ gs_plugin_add_popular (GsPlugin *plugin,
 	g_autoptr(GPtrArray) snaps = NULL;
 	guint i;
 
-	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_NONE, "featured", NULL, cancellable, error);
+	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE, "featured", NULL, cancellable, error);
 	if (snaps == NULL)
 		return FALSE;
 
@@ -528,7 +548,7 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 			g_autoptr(GPtrArray) snaps = NULL;
 			guint j;
 
-			snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_NONE, tokens[i], NULL, cancellable, error);
+			snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE, tokens[i], NULL, cancellable, error);
 			if (snaps == NULL)
 				return FALSE;
 			for (j = 0; j < snaps->len; j++) {
@@ -583,7 +603,7 @@ gs_plugin_add_search (GsPlugin *plugin,
 	guint i;
 
 	query = g_strjoinv (" ", values);
-	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_NONE, NULL, query, cancellable, error);
+	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE, NULL, query, cancellable, error);
 	if (snaps == NULL)
 		return FALSE;
 
@@ -606,7 +626,7 @@ get_store_snap (GsPlugin *plugin, const gchar *name, GCancellable *cancellable,
 	if (snap != NULL)
 		return g_object_ref (snap);
 
-	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_MATCH_NAME, NULL, name, cancellable, error);
+	snaps = find_snaps (plugin, SNAPD_FIND_FLAGS_SCOPE_WIDE | SNAPD_FIND_FLAGS_MATCH_NAME, NULL, name, cancellable, error);
 	if (snaps == NULL || snaps->len < 1)
 		return NULL;
 
@@ -825,7 +845,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 		developer_name = snapd_snap_get_publisher_username (snap);
 	gs_app_set_developer_name (app, developer_name);
 	if (snapd_snap_get_publisher_validation (snap) == SNAPD_PUBLISHER_VALIDATION_VERIFIED)
-		gs_app_add_quirk (app, AS_APP_QUIRK_DEVELOPER_VERIFIED);
+		gs_app_add_quirk (app, GS_APP_QUIRK_DEVELOPER_VERIFIED);
 
 	snap = local_snap != NULL ? local_snap : store_snap;
 	gs_app_set_version (app, snapd_snap_get_version (snap));
@@ -844,7 +864,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 			gs_app_set_metadata (app, "snap::launch-name", snapd_app_get_name (snap_app));
 			gs_app_set_metadata (app, "snap::launch-desktop", snapd_app_get_desktop_file (snap_app));
 		} else {
-			gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+			gs_app_add_quirk (app, GS_APP_QUIRK_NOT_LAUNCHABLE);
 		}
 	}
 
@@ -1043,105 +1063,3 @@ gs_plugin_app_remove (GsPlugin *plugin,
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	return TRUE;
 }
-
-gboolean
-gs_plugin_auth_login (GsPlugin *plugin, GsAuth *auth,
-		      GCancellable *cancellable, GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-	g_autoptr(SnapdClient) client = NULL;
-	g_autoptr(SnapdUserInformation) user_information = NULL;
-	g_autoptr(GVariant) macaroon_variant = NULL;
-	g_autofree gchar *serialized_macaroon = NULL;
-
-	if (auth != priv->auth)
-		return TRUE;
-
-	g_clear_object (&priv->auth_data);
-
-	client = get_client (plugin, error);
-	if (client == NULL)
-		return FALSE;
-
-	user_information = snapd_client_login2_sync (client, gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
-	if (user_information == NULL) {
-		snapd_error_convert (error);
-		return FALSE;
-	}
-
-	priv->auth_data = g_object_ref (snapd_user_information_get_auth_data (user_information));
-
-	macaroon_variant = g_variant_new ("(s^as)",
-					  snapd_auth_data_get_macaroon (priv->auth_data),
-					  snapd_auth_data_get_discharges (priv->auth_data));
-	serialized_macaroon = g_variant_print (macaroon_variant, FALSE);
-	gs_auth_add_metadata (auth, "macaroon", serialized_macaroon);
-
-	/* store */
-	if (!gs_auth_store_save (auth,
-				 GS_AUTH_STORE_FLAG_USERNAME |
-				 GS_AUTH_STORE_FLAG_METADATA,
-				 cancellable, error))
-		return FALSE;
-
-	gs_auth_add_flags (priv->auth, GS_AUTH_FLAG_VALID);
-
-	return TRUE;
-}
-
-gboolean
-gs_plugin_auth_logout (GsPlugin *plugin, GsAuth *auth,
-		       GCancellable *cancellable, GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-
-	if (auth != priv->auth)
-		return TRUE;
-
-	/* clear */
-	if (!gs_auth_store_clear (auth,
-				  GS_AUTH_STORE_FLAG_USERNAME |
-				  GS_AUTH_STORE_FLAG_METADATA,
-				  cancellable, error))
-		return FALSE;
-
-	g_clear_object (&priv->auth_data);
-	gs_auth_set_flags (priv->auth, 0);
-	return TRUE;
-}
-
-gboolean
-gs_plugin_auth_lost_password (GsPlugin *plugin, GsAuth *auth,
-			      GCancellable *cancellable, GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-
-	if (auth != priv->auth)
-		return TRUE;
-
-	// FIXME: snapd might not be using Ubuntu One accounts
-	// https://bugs.launchpad.net/bugs/1598667
-	g_set_error_literal (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_AUTH_INVALID,
-			     "do online using @https://login.ubuntu.com/+forgot_password");
-	return FALSE;
-}
-
-gboolean
-gs_plugin_auth_register (GsPlugin *plugin, GsAuth *auth,
-			 GCancellable *cancellable, GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-
-	if (auth != priv->auth)
-		return TRUE;
-
-	// FIXME: snapd might not be using Ubuntu One accounts
-	// https://bugs.launchpad.net/bugs/1598667
-	g_set_error_literal (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_AUTH_INVALID,
-			     "do online using @https://login.ubuntu.com/+login");
-	return FALSE;
-}
