@@ -172,7 +172,7 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 		break;
 	case AS_APP_STATE_UPDATABLE:
 	case AS_APP_STATE_INSTALLED:
-		if (!gs_app_has_quirk (priv->app, AS_APP_QUIRK_COMPULSORY))
+		if (!gs_app_has_quirk (priv->app, GS_APP_QUIRK_COMPULSORY))
 			gtk_widget_set_visible (priv->button, TRUE);
 		/* TRANSLATORS: this is a button next to the search results that
 		 * allows the application to be easily removed */
@@ -209,7 +209,7 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 	case AS_APP_STATE_INSTALLED:
 		gtk_widget_set_visible (priv->button,
 					!gs_app_has_quirk (priv->app,
-							   AS_APP_QUIRK_COMPULSORY));
+							   GS_APP_QUIRK_COMPULSORY));
 		break;
 	default:
 		gtk_widget_set_visible (priv->button, FALSE);
@@ -289,7 +289,7 @@ gs_app_row_refresh (GsAppRow *app_row)
 	}
 
 	/* add warning */
-	if (gs_app_has_quirk (priv->app, AS_APP_QUIRK_REMOVABLE_HARDWARE)) {
+	if (gs_app_has_quirk (priv->app, GS_APP_QUIRK_REMOVABLE_HARDWARE)) {
 		gtk_label_set_text (GTK_LABEL (priv->label_warning),
 				    /* TRANSLATORS: during the update the device
 				     * will restart into a special update-only mode */
@@ -468,10 +468,18 @@ gs_app_row_refresh (GsAppRow *app_row)
 	}
 
 	/* show the right size */
-	if (priv->show_installed_size)
+	if (priv->show_installed_size) {
 		size = gs_app_get_size_installed (priv->app);
-	else if (priv->show_update)
-		size = gs_app_get_size_download (priv->app);
+	} else if (priv->show_update) {
+		switch (gs_app_get_state (priv->app)) {
+		case AS_APP_STATE_UPDATABLE_LIVE:
+		case AS_APP_STATE_INSTALLING:
+			size = gs_app_get_size_download (priv->app);
+			break;
+		default:
+			break;
+		}
+	}
 	if (size != GS_APP_SIZE_UNKNOWABLE && size != 0) {
 		g_autofree gchar *sizestr = NULL;
 		sizestr = g_format_size (size);
@@ -480,6 +488,14 @@ gs_app_row_refresh (GsAppRow *app_row)
 	} else {
 		gtk_widget_hide (priv->label_app_size);
 	}
+
+	/* add warning */
+	if (priv->show_update &&
+	    gs_app_has_quirk (priv->app, GS_APP_QUIRK_NEW_PERMISSIONS)) {
+		gtk_label_set_text (GTK_LABEL (priv->label_warning),
+		                    _("Requires additional permissions"));
+		gtk_widget_show (priv->label_warning);
+	}
 }
 
 static void
