@@ -117,6 +117,8 @@ struct _GsDetailsPage
 	GtkWidget		*label_details_updated_title;
 	GtkWidget		*label_details_updated_value;
 	GtkWidget		*label_details_version_value;
+	GtkWidget		*label_details_permissions_title;
+	GtkWidget		*button_details_permissions_value;
 	GtkWidget		*label_failed;
 	GtkWidget		*label_license_nonfree_details;
 	GtkWidget		*label_licenses_intro;
@@ -151,6 +153,8 @@ struct _GsDetailsPage
 	GtkWidget		*label_content_rating_none;
 	GtkWidget		*button_details_rating_value;
 	GtkWidget		*label_details_rating_title;
+	GtkWidget		*popover_permissions;
+	GtkWidget		*box_permissions_details;
 };
 
 G_DEFINE_TYPE (GsDetailsPage, gs_details_page, GS_TYPE_PAGE)
@@ -222,7 +226,7 @@ gs_details_page_update_shortcut_button (GsDetailsPage *self)
 		gs_plugin_loader_get_plugin_supported (self->plugin_loader,
 						       "gs_plugin_remove_shortcut");
 
-	has_shortcut = gs_app_has_quirk (self->app, AS_APP_QUIRK_HAS_SHORTCUT);
+	has_shortcut = gs_app_has_quirk (self->app, GS_APP_QUIRK_HAS_SHORTCUT);
 
 	if (add_shortcut_func) {
 		gtk_widget_set_visible (self->button_details_add_shortcut,
@@ -872,7 +876,7 @@ gs_details_page_refresh_buttons (GsDetailsPage *self)
 	case AS_APP_STATE_INSTALLED:
 	case AS_APP_STATE_UPDATABLE:
 	case AS_APP_STATE_UPDATABLE_LIVE:
-		if (!gs_app_has_quirk (self->app, AS_APP_QUIRK_NOT_LAUNCHABLE)) {
+		if (!gs_app_has_quirk (self->app, GS_APP_QUIRK_NOT_LAUNCHABLE)) {
 			gtk_widget_set_visible (self->button_details_launch, TRUE);
 		} else {
 			gtk_widget_set_visible (self->button_details_launch, FALSE);
@@ -901,7 +905,7 @@ gs_details_page_refresh_buttons (GsDetailsPage *self)
 	}
 
 	/* remove button */
-	if (gs_app_has_quirk (self->app, AS_APP_QUIRK_COMPULSORY) ||
+	if (gs_app_has_quirk (self->app, GS_APP_QUIRK_COMPULSORY) ||
 	    gs_app_get_kind (self->app) == AS_APP_KIND_FIRMWARE) {
 		gtk_widget_set_visible (self->button_remove, FALSE);
 	} else {
@@ -944,6 +948,90 @@ gs_details_page_refresh_buttons (GsDetailsPage *self)
 	}
 }
 
+static struct {
+	GsAppPermissions permission;
+	const char *title;
+	const char *subtitle;
+} permission_display_data[] = {
+  { GS_APP_PERMISSIONS_NETWORK, N_("Network"), N_("Can communicate over the network") },
+  { GS_APP_PERMISSIONS_SYSTEM_BUS, N_("System Services"), N_("...") },
+  { GS_APP_PERMISSIONS_SESSION_BUS, N_("Session Services"), N_("...") },
+  { GS_APP_PERMISSIONS_DEVICES, N_("Devices"), N_("Can access system device files") },
+  { GS_APP_PERMISSIONS_HOME_FULL, N_("Home folder"), N_("Can view, edit and create files") },
+  { GS_APP_PERMISSIONS_HOME_READ, N_("Home folder"), N_("Can view files") },
+  { GS_APP_PERMISSIONS_FILESYSTEM_FULL, N_("File system"), N_("Can view, edit and create files") },
+  { GS_APP_PERMISSIONS_FILESYSTEM_READ, N_("File system"), N_("Can view files") },
+  { GS_APP_PERMISSIONS_DOWNLOADS_FULL, N_("Downloads folder"), N_("Can view, edit and create files") },
+  { GS_APP_PERMISSIONS_DOWNLOADS_READ, N_("Downloads folder"), N_("Can view files") },
+  { GS_APP_PERMISSIONS_SETTINGS, N_("Settings"), N_("Can view and change any settings") },
+  { GS_APP_PERMISSIONS_X11, N_("Legacy display system"), N_("Uses an old, insecure display system") },
+};
+
+static void
+populate_permission_details (GsDetailsPage *self, GsAppPermissions permissions)
+{
+	GList *children;
+
+	children = gtk_container_get_children (GTK_CONTAINER (self->box_permissions_details));
+	for (GList *l = children; l != NULL; l = l->next)
+		gtk_widget_destroy (GTK_WIDGET (l->data));
+	g_list_free (children);
+
+	if (permissions == GS_APP_PERMISSIONS_NONE) {
+		GtkWidget *label;
+		label = gtk_label_new (_("This application is fully sandboxed."));
+		gtk_label_set_xalign (GTK_LABEL (label), 0);
+		gtk_label_set_max_width_chars (GTK_LABEL (label), 40);
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_widget_show (label);
+		gtk_container_add (GTK_CONTAINER (self->box_permissions_details), label);
+	} else if (permissions == GS_APP_PERMISSIONS_UNKNOWN) {
+		GtkWidget *label;
+		label = gtk_label_new (_("Unable to determine which parts of the system "
+		                         "this application accesses. This is typical for "
+		                         "older applications."));
+		gtk_label_set_xalign (GTK_LABEL (label), 0);
+		gtk_label_set_max_width_chars (GTK_LABEL (label), 40);
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_widget_show (label);
+		gtk_container_add (GTK_CONTAINER (self->box_permissions_details), label);
+	} else {
+		for (gsize i = 0; i < G_N_ELEMENTS (permission_display_data); i++) {
+			GtkWidget *row, *image, *box, *label;
+
+			if ((permissions & permission_display_data[i].permission) == 0)
+				continue;
+
+			row = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+			gtk_widget_show (row);
+
+			image = gtk_image_new_from_icon_name ("dialog-warning-symbolic", GTK_ICON_SIZE_MENU);
+			if ((permission_display_data[i].permission & ~MEDIUM_PERMISSIONS) == 0)
+				gtk_widget_set_opacity (image, 0);
+
+			gtk_widget_show (image);
+			gtk_container_add (GTK_CONTAINER (row), image);
+
+			box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+			gtk_widget_show (box);
+			gtk_container_add (GTK_CONTAINER (row), box);
+
+			label = gtk_label_new (_(permission_display_data[i].title));
+			gtk_label_set_xalign (GTK_LABEL (label), 0);
+			gtk_widget_show (label);
+			gtk_container_add (GTK_CONTAINER (box), label);
+
+			label = gtk_label_new (_(permission_display_data[i].subtitle));
+			gtk_label_set_xalign (GTK_LABEL (label), 0);
+			gtk_style_context_add_class (gtk_widget_get_style_context (label), "dim-label");
+			gtk_widget_show (label);
+			gtk_container_add (GTK_CONTAINER (box), label);
+
+			gtk_container_add (GTK_CONTAINER (self->box_permissions_details), row);
+		}
+	}
+}
+
 static void
 gs_details_page_refresh_all (GsDetailsPage *self)
 {
@@ -958,6 +1046,7 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 	guint64 updated;
 	guint64 user_integration_bf;
 	gboolean show_support_box = FALSE;
+	g_autofree gchar *origin = NULL;
 	g_autoptr(GError) error = NULL;
 
 	/* change widgets */
@@ -1023,7 +1112,7 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		gtk_label_set_label (GTK_LABEL (self->label_details_developer_value), tmp);
 		gtk_widget_set_visible (self->label_details_developer_value, TRUE);
 	}
-	gtk_widget_set_visible (self->image_details_developer_verified, gs_app_has_quirk (self->app, AS_APP_QUIRK_DEVELOPER_VERIFIED));
+	gtk_widget_set_visible (self->image_details_developer_verified, gs_app_has_quirk (self->app, GS_APP_QUIRK_DEVELOPER_VERIFIED));
 
 	/* set the license buttons */
 	tmp = gs_app_get_license (self->app);
@@ -1102,15 +1191,20 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 	}
 
 	/* set the origin */
-	tmp = gs_app_get_origin_hostname (self->app);
-	if (tmp == NULL)
-		tmp = gs_app_get_origin (self->app);
-	if (tmp == NULL || tmp[0] == '\0') {
+	origin = g_strdup (gs_app_get_origin_hostname (self->app));
+	if (origin == NULL)
+		origin = g_strdup (gs_app_get_origin (self->app));
+	if (origin == NULL) {
+		GFile *local_file = gs_app_get_local_file (self->app);
+		if (local_file != NULL)
+			origin = g_file_get_basename (local_file);
+	}
+	if (origin == NULL || origin[0] == '\0') {
 		/* TRANSLATORS: this is where we don't know the origin of the
 		 * application */
 		gtk_label_set_label (GTK_LABEL (self->label_details_origin_value), C_("origin", "Unknown"));
 	} else {
-		gtk_label_set_label (GTK_LABEL (self->label_details_origin_value), tmp);
+		gtk_label_set_label (GTK_LABEL (self->label_details_origin_value), origin);
 	}
 
 	/* set MyLanguage kudo */
@@ -1137,7 +1231,6 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 	/* any of the various integration kudos */
 	user_integration_bf = GS_APP_KUDO_SEARCH_PROVIDER |
 			      GS_APP_KUDO_USES_NOTIFICATIONS |
-			      GS_APP_KUDO_USES_APP_MENU |
 			      GS_APP_KUDO_HIGH_CONTRAST;
 	ret = (kudos & user_integration_bf) > 0;
 	gtk_widget_set_sensitive (self->image_details_kudo_integration, ret);
@@ -1153,9 +1246,26 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		break;
 	}
 
+	if ((kudos & GS_APP_KUDO_SANDBOXED) > 0) {
+		GsAppPermissions permissions = gs_app_get_permissions (self->app);
+
+		populate_permission_details (self, permissions);
+
+		if ((permissions & ~LIMITED_PERMISSIONS) == 0)
+			gtk_button_set_label (GTK_BUTTON (self->button_details_permissions_value), _("Low"));
+		else if ((permissions & ~MEDIUM_PERMISSIONS) == 0)
+			gtk_button_set_label (GTK_BUTTON (self->button_details_permissions_value), _("Medium"));
+		else
+			gtk_button_set_label (GTK_BUTTON (self->button_details_permissions_value), _("High"));
+	} else {
+		populate_permission_details (self, GS_APP_PERMISSIONS_UNKNOWN);
+
+		gtk_button_set_label (GTK_BUTTON (self->button_details_permissions_value), _("Unknown"));
+	}
+
 	/* are we trying to replace something in the baseos */
 	gtk_widget_set_visible (self->infobar_details_package_baseos,
-				gs_app_has_quirk (self->app, AS_APP_QUIRK_COMPULSORY) &&
+				gs_app_has_quirk (self->app, GS_APP_QUIRK_COMPULSORY) &&
 				gs_app_get_state (self->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 
 	switch (gs_app_get_kind (self->app)) {
@@ -1163,7 +1273,7 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		/* installing an app with a repo file */
 		gtk_widget_set_visible (self->infobar_details_app_repo,
 					gs_app_has_quirk (self->app,
-							  AS_APP_QUIRK_HAS_SOURCE) &&
+							  GS_APP_QUIRK_HAS_SOURCE) &&
 					gs_app_get_state (self->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		gtk_widget_set_visible (self->infobar_details_repo, FALSE);
 		break;
@@ -1172,7 +1282,7 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		gtk_widget_set_visible (self->infobar_details_app_repo, FALSE);
 		gtk_widget_set_visible (self->infobar_details_repo,
 					gs_app_has_quirk (self->app,
-							  AS_APP_QUIRK_HAS_SOURCE) &&
+							  GS_APP_QUIRK_HAS_SOURCE) &&
 					gs_app_get_state (self->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		break;
 	default:
@@ -1189,7 +1299,7 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		} else {
 			gtk_widget_set_visible (self->infobar_details_app_norepo,
 						!gs_app_has_quirk (self->app,
-							  AS_APP_QUIRK_HAS_SOURCE) &&
+							  GS_APP_QUIRK_HAS_SOURCE) &&
 						gs_app_get_state (self->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		}
 		break;
@@ -1416,7 +1526,7 @@ gs_details_page_refresh_reviews (GsDetailsPage *self)
 	}
 
 	/* some apps are unreviewable */
-	if (gs_app_has_quirk (self->app, AS_APP_QUIRK_NOT_REVIEWABLE))
+	if (gs_app_has_quirk (self->app, GS_APP_QUIRK_NOT_REVIEWABLE))
 		show_reviews = FALSE;
 
 	/* set the star rating */
@@ -1697,6 +1807,22 @@ gs_details_page_load_stage1_cb (GObject *source,
 		return;
 	}
 
+	/* Hide the app if it’s not suitable for the user, but only if it’s not
+	 * already installed — a parent could have decided that a particular
+	 * app *is* actually suitable for their child, despite its age rating.
+	 *
+	 * Make it look like the app doesn’t exist, to not tantalise the
+	 * child. */
+	if (!gs_app_is_installed (self->app) &&
+	    gs_app_has_quirk (self->app, GS_APP_QUIRK_PARENTAL_FILTER)) {
+		g_autofree gchar *str = NULL;
+		const gchar *id = gs_app_get_id (self->app);
+		str = g_strdup_printf (_("Unable to find “%s”"), id == NULL ? gs_app_get_source_default (self->app) : id);
+		gtk_label_set_text (GTK_LABEL (self->label_failed), str);
+		gs_details_page_set_state (self, GS_DETAILS_PAGE_STATE_FAILED);
+		return;
+	}
+
 	/* do 2nd stage refine */
 	gs_details_page_load_stage2 (self);
 }
@@ -1717,7 +1843,7 @@ gs_details_page_file_to_app_cb (GObject *source,
 	if (list == NULL) {
 		g_warning ("failed to convert file to GsApp: %s", error->message);
 		/* go back to the overview */
-		gs_shell_change_mode (self->shell, GS_SHELL_MODE_OVERVIEW, NULL, FALSE);
+		gs_shell_set_mode (self->shell, GS_SHELL_MODE_OVERVIEW);
 	} else {
 		GsApp *app = gs_app_list_index (list, 0);
 		g_set_object (&self->app_local_file, app);
@@ -1742,7 +1868,7 @@ gs_details_page_url_to_app_cb (GObject *source,
 	if (list == NULL) {
 		g_warning ("failed to convert URL to GsApp: %s", error->message);
 		/* go back to the overview */
-		gs_shell_change_mode (self->shell, GS_SHELL_MODE_OVERVIEW, NULL, FALSE);
+		gs_shell_set_mode (self->shell, GS_SHELL_MODE_OVERVIEW);
 	} else {
 		GsApp *app = gs_app_list_index (list, 0);
 		_set_app (self, app);
@@ -2194,6 +2320,12 @@ gs_details_page_content_rating_button_cb (GtkWidget *widget, GsDetailsPage *self
 	gtk_widget_show (self->popover_content_rating);
 }
 
+static void
+gs_details_page_permissions_button_cb (GtkWidget *widget, GsDetailsPage *self)
+{
+	gtk_widget_show (self->popover_permissions);
+}
+
 static gboolean
 gs_details_page_activate_link_cb (GtkLabel *label,
                                   const gchar *uri,
@@ -2400,6 +2532,9 @@ gs_details_page_setup (GsPage *page,
 	g_signal_connect (self->button_details_rating_value, "clicked",
 			  G_CALLBACK (gs_details_page_content_rating_button_cb),
 			  self);
+	g_signal_connect (self->button_details_permissions_value, "clicked",
+			  G_CALLBACK (gs_details_page_permissions_button_cb),
+			  self);
 	g_signal_connect (self->label_details_updated_value, "activate-link",
 			  G_CALLBACK (gs_details_page_history_cb),
 			  self);
@@ -2528,6 +2663,8 @@ gs_details_page_class_init (GsDetailsPageClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_updated_title);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_updated_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_version_value);
+	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_permissions_title);
+	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, button_details_permissions_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_failed);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, list_box_addons);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, box_reviews);
@@ -2562,6 +2699,8 @@ gs_details_page_class_init (GsDetailsPageClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_content_rating_none);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, button_details_rating_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_rating_title);
+	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, popover_permissions);
+	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, box_permissions_details);
 }
 
 static void
