@@ -99,10 +99,10 @@ gs_page_authenticate_cb (GtkDialog *dialog,
 void
 gs_page_authenticate (GsPage *page,
 		      GsApp *app,
-		      const gchar *provider_id,
+		      const gchar *auth_id,
 		      GCancellable *cancellable,
-                      GsPageAuthCallback callback,
-                      gpointer user_data)
+		      GsPageAuthCallback callback,
+		      gpointer user_data)
 {
 	GsPagePrivate *priv = gs_page_get_instance_private (page);
 	g_autoptr(GsPageHelper) helper = NULL;
@@ -117,7 +117,7 @@ gs_page_authenticate (GsPage *page,
 
 	dialog = gs_auth_dialog_new (priv->plugin_loader,
 				     app,
-				     provider_id,
+				     auth_id,
 				     &error);
 	if (dialog == NULL) {
 		g_warning ("%s", error->message);
@@ -565,7 +565,7 @@ gs_page_notify_quirk_cb (GsApp *app, GParamSpec *pspec, GsPageHelper *helper)
 {
 	gtk_widget_set_sensitive (helper->button_install,
 				  !gs_app_has_quirk (helper->app,
-						     AS_APP_QUIRK_NEEDS_USER_ACTION));
+						     GS_APP_QUIRK_NEEDS_USER_ACTION));
 }
 
 static void
@@ -637,7 +637,7 @@ gs_page_update_app (GsPage *page, GsApp *app, GCancellable *cancellable)
 
 	/* tell the user what they have to do */
 	if (gs_app_get_kind (app) == AS_APP_KIND_FIRMWARE &&
-	    gs_app_has_quirk (app, AS_APP_QUIRK_NEEDS_USER_ACTION)) {
+	    gs_app_has_quirk (app, GS_APP_QUIRK_NEEDS_USER_ACTION)) {
 		GPtrArray *screenshots = gs_app_get_screenshots (app);
 		if (screenshots->len > 0) {
 			AsScreenshot *ss = g_ptr_array_index (screenshots, 0);
@@ -720,14 +720,14 @@ gs_page_remove_app (GsPage *page, GsApp *app, GCancellable *cancellable)
 	switch (gs_app_get_kind (app)) {
 	case AS_APP_KIND_SOURCE:
 		/* TRANSLATORS: this is a prompt message, and '%s' is an
-		 * source name, e.g. 'GNOME Nightly' */
+		 * repository name, e.g. 'GNOME Nightly' */
 		title = g_strdup_printf (_("Are you sure you want to remove "
-					   "the %s source?"),
+					   "the %s repository?"),
 					 gs_app_get_name (app));
 		/* TRANSLATORS: longer dialog text */
 		message = g_strdup_printf (_("All applications from %s will be "
 					     "removed, and you will have to "
-					     "re-install the source to use them again."),
+					     "re-install the repository to use them again."),
 					   gs_app_get_name (app));
 		break;
 	default:
