@@ -63,7 +63,7 @@ void		 gs_page_set_header_end_widget		(GsPage		*page,
 							 GtkWidget	*widget);
 void		 gs_page_authenticate			(GsPage			*page,
 							 GsApp			*app,
-							 const gchar		*provider_id,
+							 const gchar		*auth_id,
 							 GCancellable		*cancellable,
 							 GsPageAuthCallback	 callback,
 							 gpointer		 user_data);
