@@ -38,6 +38,7 @@ struct _GsPopularTile
 	GtkWidget	*eventbox;
 	GtkWidget	*stack;
 	GtkWidget	*stars;
+	guint		 app_state_changed_id;
 };
 
 G_DEFINE_TYPE (GsPopularTile, gs_popular_tile, GS_TYPE_APP_TILE)
@@ -56,6 +57,8 @@ app_state_changed_idle (gpointer user_data)
 	gboolean installed;
 	g_autofree gchar *name = NULL;
 
+	tile->app_state_changed_id = 0;
+
 	accessible = gtk_widget_get_accessible (GTK_WIDGET (tile));
 
 	switch (gs_app_get_state (tile->app)) {
@@ -83,14 +86,14 @@ app_state_changed_idle (gpointer user_data)
 		atk_object_set_description (accessible, gs_app_get_summary (tile->app));
 	}
 
-	g_object_unref (tile);
 	return G_SOURCE_REMOVE;
 }
 
 static void
 app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 {
-	g_idle_add (app_state_changed_idle, g_object_ref (tile));
+	g_clear_handle_id (&tile->app_state_changed_id, g_source_remove);
+	tile->app_state_changed_id = g_idle_add (app_state_changed_idle, tile);
 }
 
 static void
@@ -101,8 +104,9 @@ gs_popular_tile_set_app (GsAppTile *app_tile, GsApp *app)
 
 	g_return_if_fail (GS_IS_APP (app) || app == NULL);
 
-	if (tile->app)
+	if (tile->app != NULL)
 		g_signal_handlers_disconnect_by_func (tile->app, app_state_changed, tile);
+	g_clear_handle_id (&tile->app_state_changed_id, g_source_remove);
 
 	g_set_object (&tile->app, app);
 	if (!app)
@@ -145,9 +149,9 @@ gs_popular_tile_destroy (GtkWidget *widget)
 {
 	GsPopularTile *tile = GS_POPULAR_TILE (widget);
 
-	if (tile->app)
+	if (tile->app != NULL)
 		g_signal_handlers_disconnect_by_func (tile->app, app_state_changed, tile);
-
+	g_clear_handle_id (&tile->app_state_changed_id, g_source_remove);
 	g_clear_object (&tile->app);
 
 	GTK_WIDGET_CLASS (gs_popular_tile_parent_class)->destroy (widget);
