@@ -80,7 +80,7 @@ typedef struct
 	gulong			 search_changed_id;
 	gchar			*events_info_uri;
 	gboolean		 in_mode_change;
-	GsPage			*page_last;
+	GsPage			*page;
 	GSimpleActionGroup	*auth_actions;
 } GsShellPrivate;
 
@@ -351,9 +351,9 @@ gs_shell_change_mode (GsShell *shell,
 
 	priv->in_mode_change = TRUE;
 
-	if (priv->page_last)
-		gs_page_switch_from (priv->page_last);
-	g_set_object (&priv->page_last, page);
+	if (priv->page != NULL)
+		gs_page_switch_from (priv->page);
+	g_set_object (&priv->page, page);
 	gs_page_switch_to (page, scroll_up);
 	priv->in_mode_change = FALSE;
 
@@ -538,13 +538,24 @@ gs_shell_back_button_cb (GtkWidget *widget, GsShell *shell)
 }
 
 static void
-initial_overview_load_done (GsOverviewPage *overview_page, gpointer data)
+gs_shell_reload_cb (GsPluginLoader *plugin_loader, GsShell *shell)
+{
+	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+	g_autoptr(GList) keys = g_hash_table_get_keys (priv->pages);
+	for (GList *l = keys; l != NULL; l = l->next) {
+		GsPage *page = GS_PAGE (g_hash_table_lookup (priv->pages, l->data));
+		gs_page_reload (page);
+	}
+}
+
+static void
+initial_refresh_done (GsLoadingPage *loading_page, gpointer data)
 {
 	GsPage *page;
 	GsShell *shell = data;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 
-	g_signal_handlers_disconnect_by_func (overview_page, initial_overview_load_done, data);
+	g_signal_handlers_disconnect_by_func (loading_page, initial_refresh_done, data);
 
 	page = GS_PAGE (gtk_builder_get_object (priv->builder, "updates_page"));
 	gs_page_reload (page);
@@ -552,6 +563,14 @@ initial_overview_load_done (GsOverviewPage *overview_page, gpointer data)
 	gs_page_reload (page);
 
 	g_signal_emit (shell, signals[SIGNAL_LOADED], 0);
+
+	/* go to OVERVIEW, unless the "loading" callbacks changed mode already */
+	if (priv->mode == GS_SHELL_MODE_LOADING)
+		gs_shell_change_mode (shell, GS_SHELL_MODE_OVERVIEW, NULL, TRUE);
+
+	/* now that we're finished with the loading page, connect the reload signal handler */
+	g_signal_connect (priv->plugin_loader, "reload",
+	                  G_CALLBACK (gs_shell_reload_cb), shell);
 }
 
 static gboolean
@@ -637,86 +656,104 @@ static void
 signin_activated_cb (GSimpleAction *action, GVariant *parameter, GsShell *shell)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	const gchar *action_name, *provider_id;
+	const gchar *action_name, *auth_id;
 	GsAuth *auth;
 
 	action_name = g_action_get_name (G_ACTION (action));
 	g_return_if_fail (g_str_has_prefix (action_name, "signin-"));
-	provider_id = action_name + strlen ("signin-");
+	auth_id = action_name + strlen ("signin-");
 
-	auth = gs_plugin_loader_get_auth_by_id (priv->plugin_loader, provider_id);
+	auth = gs_plugin_loader_get_auth_by_id (priv->plugin_loader, auth_id);
 	g_return_if_fail (auth != NULL);
 
-	gs_page_authenticate (priv->page_last, NULL,
-			      gs_auth_get_provider_id (auth),
+	gs_page_authenticate (priv->page, NULL,
+			      gs_auth_get_auth_id (auth),
 			      priv->cancellable,
 			      NULL, NULL);
 }
 
-static void
-gs_shell_logout_cb (GObject *source,
-		    GAsyncResult *res,
-		    gpointer user_data)
-{
-	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source);
-	g_autoptr(GError) error = NULL;
-
-	if (!gs_plugin_loader_job_action_finish (plugin_loader, res, &error)) {
-		g_warning ("failed to logout: %s",  error->message);
-		return;
-	}
-}
-
 static void
 signout_activated_cb (GSimpleAction *action, GVariant *parameter, GsShell *shell)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	const gchar *action_name, *provider_id;
+	const gchar *action_name, *auth_id;
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 	GsAuth *auth;
 
 	action_name = g_action_get_name (G_ACTION (action));
 	g_return_if_fail (g_str_has_prefix (action_name, "signout-"));
-	provider_id = action_name + strlen ("signout-");
+	auth_id = action_name + strlen ("signout-");
 
-	auth = gs_plugin_loader_get_auth_by_id (priv->plugin_loader, provider_id);
+	auth = gs_plugin_loader_get_auth_by_id (priv->plugin_loader, auth_id);
 	g_return_if_fail (auth != NULL);
 
-	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_AUTH_LOGOUT,
-					 "interactive", TRUE,
-					 "auth", auth,
-					 NULL);
-
-	gs_plugin_loader_job_process_async (priv->plugin_loader, plugin_job,
-					    priv->cancellable,
-					    gs_shell_logout_cb,
-					    shell);
+	gs_auth_set_goa_object (auth, NULL);
 }
 
 static void
-menu_button_clicked_cb (GtkButton *button, GsShell *shell)
+gs_shell_reload_auth_menus (GsShell *shell)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
+	GMenu *accounts_menu;
 	GPtrArray *auth_array;
 
+	accounts_menu = G_MENU (gtk_builder_get_object (priv->builder, "accounts_menu"));
+	g_menu_remove_all (accounts_menu);
+
 	auth_array = gs_plugin_loader_get_auths (priv->plugin_loader);
 	for (guint i = 0; i < auth_array->len; i++) {
 		GsAuth *auth = g_ptr_array_index (auth_array, i);
 		gboolean logged_in;
 		g_autofree gchar *signin_action_name = NULL;
 		GSimpleAction *signin_action;
+		g_autofree gchar *signin_target = NULL;
 		g_autofree gchar *signout_action_name = NULL;
 		GSimpleAction *signout_action;
+		g_autofree gchar *signout_target = NULL;
+		GoaObject *goa_object;
+		g_autofree gchar *signin_label = NULL;
+		g_autofree gchar *signout_label = NULL;
+		g_autoptr(GMenu) auth_menu = NULL;
+		g_autoptr(GMenuItem) signin_item = NULL;
+		g_autoptr(GMenuItem) signout_item = NULL;
 
-		logged_in = gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID);
 
-		signin_action_name = g_strdup_printf ("signin-%s", gs_auth_get_provider_id (auth));
+		goa_object = gs_auth_peek_goa_object (auth);
+		logged_in = goa_object != NULL;
+
+		auth_menu = g_menu_new ();
+		accounts_menu = G_MENU (gtk_builder_get_object (priv->builder, "accounts_menu"));
+		g_menu_append_section (accounts_menu, gs_auth_get_provider_name (auth), G_MENU_MODEL (auth_menu));
+
+		signin_action_name = g_strdup_printf ("signin-%s", gs_auth_get_auth_id (auth));
 		signin_action = G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (priv->auth_actions), signin_action_name));
 		g_simple_action_set_enabled (signin_action, !logged_in);
 
-		signout_action_name = g_strdup_printf ("signout-%s", gs_auth_get_provider_id (auth));
+		signout_action_name = g_strdup_printf ("signout-%s", gs_auth_get_auth_id (auth));
 		signout_action = G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (priv->auth_actions), signout_action_name));
 		g_simple_action_set_enabled (signout_action, logged_in);
+
+
+		if (logged_in) {
+			GoaAccount *goa_account = goa_object_peek_account (goa_object);
+
+			/* TRANSLATORS: menu item that signs into the named account with a particular username */
+			signin_label = g_strdup_printf (_("Signed in as %s"),
+							goa_account_get_presentation_identity (goa_account));
+		} else {
+			/* TRANSLATORS: menu item that signs into the named account */
+			signin_label = g_strdup_printf (_("Sign in…"));
+		}
+
+		signin_target = g_strdup_printf ("auth.%s", signin_action_name);
+		signin_item = g_menu_item_new (signin_label, signin_target);
+		g_menu_append_item (auth_menu, signin_item);
+
+		/* TRANSLATORS: menu item for signing out from the named account */
+		signout_label = g_strdup_printf (_("Sign out"));
+		signout_target = g_strdup_printf ("auth.%s", signout_action_name);
+		signout_item = g_menu_item_new (signout_label, signout_target);
+		g_menu_append_item (auth_menu, signout_item);
 	}
 }
 
@@ -771,7 +808,6 @@ static gboolean
 main_window_closed_cb (GtkWidget *dialog, GdkEvent *event, gpointer user_data)
 {
 	GsShell *shell = user_data;
-	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 
 	/* hide any notifications */
 	g_application_withdraw_notification (g_application_get_default (),
@@ -779,25 +815,11 @@ main_window_closed_cb (GtkWidget *dialog, GdkEvent *event, gpointer user_data)
 	g_application_withdraw_notification (g_application_get_default (),
 					     "install-resources");
 
-	/* When the window is closed, reset the initial mode to overview */
-	priv->mode = GS_SHELL_MODE_OVERVIEW;
-
 	gs_shell_clean_back_entry_stack (shell);
 	gtk_widget_hide (dialog);
 	return TRUE;
 }
 
-static void
-gs_shell_reload_cb (GsPluginLoader *plugin_loader, GsShell *shell)
-{
-	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	g_autoptr(GList) keys = g_hash_table_get_keys (priv->pages);
-	for (GList *l = keys; l != NULL; l = l->next) {
-		GsPage *page = GS_PAGE (g_hash_table_lookup (priv->pages, l->data));
-		gs_page_reload (page);
-	}
-}
-
 static void
 gs_shell_main_window_mapped_cb (GtkWidget *widget, GsShell *shell)
 {
@@ -938,16 +960,6 @@ gs_shell_get_title_from_app (GsApp *app)
 	return g_strdup_printf (_("“%s”"), gs_app_get_id (app));
 }
 
-static gboolean
-gs_shell_show_detailed_error (GsShell *shell, const GError *error)
-{
-	if (error->code == GS_PLUGIN_ERROR_FAILED)
-		return TRUE;
-	if (error->code == GS_PLUGIN_ERROR_DOWNLOAD_FAILED)
-		return TRUE;
-	return FALSE;
-}
-
 static gchar *
 get_first_line (const gchar *str)
 {
@@ -977,6 +989,7 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 	GsShellEventButtons buttons = GS_SHELL_EVENT_BUTTON_NONE;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	const GError *error = gs_plugin_event_get_error (event);
+	GsPluginAction action = gs_plugin_event_get_action (event);
 	g_autofree gchar *str_origin = NULL;
 	g_autoptr(GString) str = g_string_new (NULL);
 
@@ -1002,6 +1015,7 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 			/* TRANSLATORS: failure text for the in-app notification */
 			g_string_append (str, _("Unable to download updates"));
 		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	case GS_PLUGIN_ERROR_NO_NETWORK:
 		/* TRANSLATORS: failure text for the in-app notification */
@@ -1025,7 +1039,6 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 		buttons |= GS_SHELL_EVENT_BUTTON_NO_SPACE;
 		break;
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification */
 		g_string_append (str, _("Unable to download updates: "
 				        "authentication was required"));
@@ -1046,8 +1059,14 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 		/* non-interactive generic */
 		if (!gs_plugin_event_has_flag (event, GS_PLUGIN_EVENT_FLAG_INTERACTIVE))
 			return FALSE;
-		/* TRANSLATORS: failure text for the in-app notification */
-		g_string_append (str, _("Unable to get list of updates"));
+		if (action == GS_PLUGIN_ACTION_DOWNLOAD) {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append (str, _("Unable to download updates"));
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append (str, _("Unable to get list of updates"));
+		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1063,10 +1082,6 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1083,7 +1098,6 @@ gs_shell_show_event_purchase (GsShell *shell, GsPluginEvent *event)
 	str_app = gs_shell_get_title_from_app (app);
 	switch (error->code) {
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "GIMP") */
 		g_string_append_printf (str, _("Unable to purchase %s: "
@@ -1115,15 +1129,12 @@ gs_shell_show_event_purchase (GsShell *shell, GsPluginEvent *event)
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "GIMP") */
 		g_string_append_printf (str, _("Unable to purchase %s"), str_app);
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
 		return FALSE;
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, GS_SHELL_EVENT_BUTTON_NONE);
 	return TRUE;
@@ -1160,6 +1171,7 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 						       "as download failed"),
 						str_app);
 		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	case GS_PLUGIN_ERROR_NOT_SUPPORTED:
 		if (origin != NULL) {
@@ -1198,7 +1210,6 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 		buttons |= GS_SHELL_EVENT_BUTTON_NO_SPACE;
 		break;
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification */
 		g_string_append_printf (str, _("Unable to install %s: "
 					       "authentication was required"),
@@ -1219,35 +1230,6 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 					       "install software"),
 					str_app);
 		break;
-	case GS_PLUGIN_ERROR_ACCOUNT_SUSPENDED:
-	case GS_PLUGIN_ERROR_ACCOUNT_DEACTIVATED:
-		if (origin != NULL) {
-			const gchar *url_homepage;
-
-			/* TRANSLATORS: failure text for the in-app notification,
-			 * the %s is the name of the authentication service,
-			 * e.g. "Ubuntu One" */
-			g_string_append_printf (str, _("Your %s account has been suspended."),
-						gs_app_get_name (origin));
-			g_string_append (str, " ");
-			/* TRANSLATORS: failure text for the in-app notification */
-			g_string_append (str, _("It is not possible to install "
-						"software until this has been resolved."));
-			url_homepage = gs_app_get_url (origin, AS_URL_KIND_HOMEPAGE);
-			if (url_homepage != NULL) {
-				g_autofree gchar *url = NULL;
-				url = g_strdup_printf ("<a href=\"%s\">%s</a>",
-						       url_homepage,
-						       url_homepage);
-				/* TRANSLATORS: failure text for the in-app notification,
-				 * where the %s is the clickable link (e.g.
-				 * "http://example.com/what-did-i-do-wrong/") */
-				msg = g_strdup_printf (_("For more information, visit %s."),
-							url);
-				g_string_append_printf (str, " %s", msg);
-			}
-		}
-		break;
 	case GS_PLUGIN_ERROR_AC_POWER_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "Dell XPS 13") */
@@ -1261,6 +1243,7 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "GIMP") */
 		g_string_append_printf (str, _("Unable to install %s"), str_app);
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1276,10 +1259,6 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1297,24 +1276,36 @@ gs_shell_show_event_update (GsShell *shell, GsPluginEvent *event)
 	g_autofree gchar *str_origin = NULL;
 	g_autoptr(GString) str = g_string_new (NULL);
 
-	str_app = gs_shell_get_title_from_app (app);
 	switch (error->code) {
 	case GS_PLUGIN_ERROR_DOWNLOAD_FAILED:
-		if (origin != NULL) {
+		if (app != NULL && origin != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
 			str_origin = gs_shell_get_title_from_origin (origin);
 			/* TRANSLATORS: failure text for the in-app notification,
 			 * where the first %s is the app name (e.g. "GIMP") and
 			 * the second %s is the origin, e.g. "Fedora" or
 			 * "Fedora Project [fedoraproject.org]" */
-			g_string_append_printf (str, _("Unable to update %s from %s"),
+			g_string_append_printf (str, _("Unable to update %s from %s as download failed"),
 					       str_app, str_origin);
 			buttons = TRUE;
-		} else {
+		} else if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
 			/* TRANSLATORS: failure text for the in-app notification,
 			 * where the %s is the application name (e.g. "GIMP") */
 			g_string_append_printf (str, _("Unable to update %s as download failed"),
 						str_app);
+		} else if (origin != NULL) {
+			str_origin = gs_shell_get_title_from_origin (origin);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the origin, e.g. "Fedora" or
+			 * "Fedora Project [fedoraproject.org]" */
+			g_string_append_printf (str, _("Unable to install updates from %s as download failed"),
+						str_origin);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates as download failed"));
 		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	case GS_PLUGIN_ERROR_NO_NETWORK:
 		/* TRANSLATORS: failure text for the in-app notification */
@@ -1324,49 +1315,92 @@ gs_shell_show_event_update (GsShell *shell, GsPluginEvent *event)
 		buttons |= GS_SHELL_EVENT_BUTTON_NETWORK_SETTINGS;
 		break;
 	case GS_PLUGIN_ERROR_NO_SPACE:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "GIMP") */
-		g_string_append_printf (str, _("Unable to update %s: "
-					       "not enough disk space"),
-					str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("Unable to update %s: "
+						       "not enough disk space"),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates: "
+						       "not enough disk space"));
+		}
 		buttons |= GS_SHELL_EVENT_BUTTON_NO_SPACE;
 		break;
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "GIMP") */
-		g_string_append_printf (str, _("Unable to update %s: "
-					       "authentication was required"),
-					str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("Unable to update %s: "
+						       "authentication was required"),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates: "
+						       "authentication was required"));
+		}
 		break;
 	case GS_PLUGIN_ERROR_AUTH_INVALID:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "GIMP") */
-		g_string_append_printf (str, _("Unable to update %s: "
-					       "authentication was invalid"),
-					str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("Unable to update %s: "
+						       "authentication was invalid"),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates: "
+						       "authentication was invalid"));
+		}
 		break;
 	case GS_PLUGIN_ERROR_NO_SECURITY:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "GIMP") */
-		g_string_append_printf (str, _("Unable to update %s: "
-					       "you do not have permission to "
-					       "update software"),
-					str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("Unable to update %s: "
+						       "you do not have permission to "
+						       "update software"),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates: "
+						       "you do not have permission to "
+						       "update software"));
+		}
 		break;
 	case GS_PLUGIN_ERROR_AC_POWER_REQUIRED:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "Dell XPS 13") */
-		g_string_append_printf (str, _("Unable to update %s: "
-					       "AC power is required"),
-					str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "Dell XPS 13") */
+			g_string_append_printf (str, _("Unable to update %s: "
+						       "AC power is required"),
+						str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "Dell XPS 13") */
+			g_string_append_printf (str, _("Unable to install updates: "
+						       "AC power is required"));
+		}
 		break;
 	case GS_PLUGIN_ERROR_CANCELLED:
 		break;
 	default:
-		/* TRANSLATORS: failure text for the in-app notification,
-		 * where the %s is the application name (e.g. "GIMP") */
-		g_string_append_printf (str, _("Unable to update %s"), str_app);
+		if (app != NULL) {
+			str_app = gs_shell_get_title_from_app (app);
+			/* TRANSLATORS: failure text for the in-app notification,
+			 * where the %s is the application name (e.g. "GIMP") */
+			g_string_append_printf (str, _("Unable to update %s"), str_app);
+		} else {
+			/* TRANSLATORS: failure text for the in-app notification */
+			g_string_append_printf (str, _("Unable to install updates"));
+		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1382,10 +1416,6 @@ gs_shell_show_event_update (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1420,12 +1450,15 @@ gs_shell_show_event_upgrade (GsShell *shell, GsPluginEvent *event)
 						       "as download failed"),
 						str_app);
 		}
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	case GS_PLUGIN_ERROR_NO_NETWORK:
-		/* TRANSLATORS: failure text for the in-app notification */
-		g_string_append (str, _("Unable to upgrade: "
-					"internet access was required but "
-					"wasn’t available"));
+		/* TRANSLATORS: failure text for the in-app notification,
+		 * where the %s is the distro name (e.g. "Fedora 25") */
+		g_string_append_printf (str, _("Unable to upgrade to %s: "
+					       "internet access was required but "
+					       "wasn’t available"),
+					str_app);
 		buttons |= GS_SHELL_EVENT_BUTTON_NETWORK_SETTINGS;
 		break;
 	case GS_PLUGIN_ERROR_NO_SPACE:
@@ -1437,7 +1470,6 @@ gs_shell_show_event_upgrade (GsShell *shell, GsPluginEvent *event)
 		buttons |= GS_SHELL_EVENT_BUTTON_NO_SPACE;
 		break;
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the distro name (e.g. "Fedora 25") */
 		g_string_append_printf (str, _("Unable to upgrade to %s: "
@@ -1471,6 +1503,7 @@ gs_shell_show_event_upgrade (GsShell *shell, GsPluginEvent *event)
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the distro name (e.g. "Fedora 25") */
 		g_string_append_printf (str, _("Unable to upgrade to %s"), str_app);
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1486,10 +1519,6 @@ gs_shell_show_event_upgrade (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1509,7 +1538,6 @@ gs_shell_show_event_remove (GsShell *shell, GsPluginEvent *event)
 	str_app = gs_shell_get_title_from_app (app);
 	switch (error->code) {
 	case GS_PLUGIN_ERROR_AUTH_REQUIRED:
-	case GS_PLUGIN_ERROR_PIN_REQUIRED:
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "GIMP") */
 		g_string_append_printf (str, _("Unable to remove %s: authentication was required"),
@@ -1544,6 +1572,7 @@ gs_shell_show_event_remove (GsShell *shell, GsPluginEvent *event)
 		/* TRANSLATORS: failure text for the in-app notification,
 		 * where the %s is the application name (e.g. "GIMP") */
 		g_string_append_printf (str, _("Unable to remove %s"), str_app);
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1559,10 +1588,6 @@ gs_shell_show_event_remove (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1608,6 +1633,7 @@ gs_shell_show_event_launch (GsShell *shell, GsPluginEvent *event)
 			return FALSE;
 		/* TRANSLATORS: we failed to get a proper error code */
 		g_string_append (str, _("Sorry, something went wrong"));
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1623,10 +1649,6 @@ gs_shell_show_event_launch (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1662,15 +1684,12 @@ gs_shell_show_event_file_to_app (GsShell *shell, GsPluginEvent *event)
 			return FALSE;
 		/* TRANSLATORS: we failed to get a proper error code */
 		g_string_append (str, _("Sorry, something went wrong"));
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
 		return FALSE;
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1706,15 +1725,12 @@ gs_shell_show_event_url_to_app (GsShell *shell, GsPluginEvent *event)
 			return FALSE;
 		/* TRANSLATORS: we failed to get a proper error code */
 		g_string_append (str, _("Sorry, something went wrong"));
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
 		return FALSE;
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		g_string_append_printf (str, "\n%s", error->message);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1776,6 +1792,7 @@ gs_shell_show_event_fallback (GsShell *shell, GsPluginEvent *event)
 			return FALSE;
 		/* TRANSLATORS: we failed to get a proper error code */
 		g_string_append (str, _("Sorry, something went wrong"));
+		gs_shell_append_detailed_error (shell, str, error);
 		break;
 	}
 	if (str->len == 0)
@@ -1791,10 +1808,6 @@ gs_shell_show_event_fallback (GsShell *shell, GsPluginEvent *event)
 		}
 	}
 
-	/* add extra debugging for debug builds */
-	if (gs_shell_show_detailed_error (shell, error))
-		gs_shell_append_detailed_error (shell, str, error);
-
 	/* show in-app notification */
 	gs_shell_show_event_app_notify (shell, str->str, buttons);
 	return TRUE;
@@ -1822,11 +1835,11 @@ gs_shell_show_event (GsShell *shell, GsPluginEvent *event)
 	action = gs_plugin_event_get_action (event);
 	switch (action) {
 	case GS_PLUGIN_ACTION_REFRESH:
+	case GS_PLUGIN_ACTION_DOWNLOAD:
 		return gs_shell_show_event_refresh (shell, event);
 	case GS_PLUGIN_ACTION_PURCHASE:
 		return gs_shell_show_event_purchase (shell, event);
 	case GS_PLUGIN_ACTION_INSTALL:
-	case GS_PLUGIN_ACTION_DOWNLOAD:
 		return gs_shell_show_event_install (shell, event);
 	case GS_PLUGIN_ACTION_UPDATE:
 		return gs_shell_show_event_update (shell, event);
@@ -1851,9 +1864,9 @@ gs_shell_show_event (GsShell *shell, GsPluginEvent *event)
 static void
 gs_shell_rescan_events (GsShell *shell)
 {
-	GsPluginEvent *event;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	GtkWidget *widget;
+	g_autoptr(GsPluginEvent) event = NULL;
 
 	/* find the first active event and show it */
 	event = gs_plugin_loader_get_event_default (priv->plugin_loader);
@@ -1878,7 +1891,6 @@ gs_shell_rescan_events (GsShell *shell)
 	}
 
 	/* nothing to show */
-	g_debug ("no events to show");
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "notification_event"));
 	gtk_revealer_set_reveal_child (GTK_REVEALER (widget), FALSE);
 }
@@ -1960,8 +1972,6 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	g_return_if_fail (GS_IS_SHELL (shell));
 
 	priv->plugin_loader = g_object_ref (plugin_loader);
-	g_signal_connect (priv->plugin_loader, "reload",
-			  G_CALLBACK (gs_shell_reload_cb), shell);
 	g_signal_connect_object (priv->plugin_loader, "notify::events",
 				 G_CALLBACK (gs_shell_events_notify_cb),
 				 shell, 0);
@@ -2014,10 +2024,10 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	                  shell);
 
 	/* show the account popover when clicking on the account button */
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "menu_button"));
+	/* widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "menu_button"));
 	g_signal_connect (widget, "clicked",
 	                  G_CALLBACK (menu_button_clicked_cb),
-	                  shell);
+	                  shell); */
 
 	/* setup buttons */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_back"));
@@ -2094,7 +2104,7 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	/* load content */
 	page = GS_PAGE (gtk_builder_get_object (priv->builder, "loading_page"));
 	g_signal_connect (page, "refreshed",
-			  G_CALLBACK (initial_overview_load_done), shell);
+			  G_CALLBACK (initial_refresh_done), shell);
 
 	/* coldplug */
 	gs_shell_rescan_events (shell);
@@ -2108,77 +2118,34 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 	auth_array = gs_plugin_loader_get_auths (priv->plugin_loader);
 	for (guint i = 0; i < auth_array->len; i++) {
 		GsAuth *auth = g_ptr_array_index (auth_array, i);
-		GMenu *accounts_menu;
-		gboolean logged_in;
-		g_autoptr(GMenu) auth_menu = NULL;
 		g_autoptr(GSimpleAction) signin_action = NULL;
 		g_autofree gchar *signin_action_name = NULL;
-		g_autoptr(GMenuItem) signin_item = NULL;
-		g_autofree gchar *signin_label = NULL;
-		g_autofree gchar *signin_target = NULL;
 		g_autoptr(GSimpleAction) signout_action = NULL;
 		g_autofree gchar *signout_action_name = NULL;
-		g_autoptr(GMenuItem) signout_item = NULL;
-		g_autofree gchar *signout_label = NULL;
-		g_autofree gchar *signout_target = NULL;
 
-		logged_in = gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID);
-
-		signin_action_name = g_strdup_printf ("signin-%s", gs_auth_get_provider_id (auth));
+		signin_action_name = g_strdup_printf ("signin-%s", gs_auth_get_auth_id (auth));
 		signin_action = g_simple_action_new (signin_action_name, NULL);
-		g_simple_action_set_enabled (signin_action, !logged_in);
 		g_signal_connect (signin_action, "activate", G_CALLBACK (signin_activated_cb), shell);
 		g_action_map_add_action (G_ACTION_MAP (priv->auth_actions), G_ACTION (signin_action));
 
-		signout_action_name = g_strdup_printf ("signout-%s", gs_auth_get_provider_id (auth));
+		signout_action_name = g_strdup_printf ("signout-%s", gs_auth_get_auth_id (auth));
 		signout_action = g_simple_action_new (signout_action_name, NULL);
-		g_simple_action_set_enabled (signout_action, logged_in);
 		g_signal_connect (signout_action, "activate", G_CALLBACK (signout_activated_cb), shell);
 		g_action_map_add_action (G_ACTION_MAP (priv->auth_actions), G_ACTION (signout_action));
 
-		auth_menu = g_menu_new ();
-		accounts_menu = G_MENU (gtk_builder_get_object (priv->builder, "accounts_menu"));
-		g_menu_append_section (accounts_menu, NULL, G_MENU_MODEL (auth_menu));
-
-		if (logged_in) {
-			/* TRANSLATORS: menu item that signs into the named account with a particular username */
-			signin_label = g_strdup_printf (_("Signed in into %s as %s"),
-							gs_auth_get_provider_name (auth),
-							gs_auth_get_username (auth));
-		} else {
-			/* TRANSLATORS: menu item that signs into the named account */
-			signin_label = g_strdup_printf (_("Sign in to %s…"),
-							gs_auth_get_provider_name (auth));
-		}
-		signin_target = g_strdup_printf ("auth.%s", signin_action_name);
-		signin_item = g_menu_item_new (signin_label, signin_target);
-		g_menu_append_item (auth_menu, signin_item);
-
-		/* TRANSLATORS: menu item for signing out from the named account */
-		signout_label = g_strdup_printf (_("Sign out from %s"),
-						 gs_auth_get_provider_name (auth));
-		signout_target = g_strdup_printf ("auth.%s", signout_action_name);
-		signout_item = g_menu_item_new (signout_label, signout_target);
-		g_menu_append_item (auth_menu, signout_item);
+		g_signal_connect_object (auth, "changed",
+					 G_CALLBACK (gs_shell_reload_auth_menus),
+					 shell, G_CONNECT_SWAPPED);
+		gs_shell_reload_auth_menus (shell);
 	}
+
+	/* show loading page, which triggers the initial refresh */
+	gs_shell_change_mode (shell, GS_SHELL_MODE_LOADING, NULL, TRUE);
 }
 
 void
 gs_shell_set_mode (GsShell *shell, GsShellMode mode)
 {
-	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
-	guint matched;
-
-	/* if we're loading a different mode at startup then don't wait for
-	 * the overview page to load before showing content */
-	if (mode != GS_SHELL_MODE_OVERVIEW) {
-		GsPage *page = g_hash_table_lookup (priv->pages, "overview");
-		matched = g_signal_handlers_disconnect_by_func (page,
-								initial_overview_load_done,
-								shell);
-		if (matched > 0)
-			g_signal_emit (shell, signals[SIGNAL_LOADED], 0);
-	}
 	gs_shell_change_mode (shell, mode, NULL, TRUE);
 }
 
@@ -2344,7 +2311,7 @@ gs_shell_dispose (GObject *object)
 	g_clear_object (&priv->plugin_loader);
 	g_clear_object (&priv->header_start_widget);
 	g_clear_object (&priv->header_end_widget);
-	g_clear_object (&priv->page_last);
+	g_clear_object (&priv->page);
 	g_clear_pointer (&priv->pages, g_hash_table_unref);
 	g_clear_pointer (&priv->events_info_uri, g_free);
 	g_clear_pointer (&priv->modal_dialogs, g_ptr_array_unref);
