@@ -53,15 +53,8 @@ struct _GsUpdateMonitor {
 
 G_DEFINE_TYPE (GsUpdateMonitor, gs_update_monitor, G_TYPE_OBJECT)
 
-typedef enum {
-	GS_UPDATE_MONITOR_MODE_NONE		= 0,
-	GS_UPDATE_MONITOR_MODE_DO_AUTOUPDATES	= 1 << 0,
-	GS_UPDATE_MONITOR_MODE_LAST
-} GsUpdateMonitorMode;
-
 typedef struct {
 	GsUpdateMonitor		*monitor;
-	GsUpdateMonitorMode	 mode;
 } DownloadUpdatesData;
 
 static void
@@ -213,7 +206,7 @@ _build_autoupdated_notification (GsUpdateMonitor *monitor, GsAppList *list)
 	/* how many apps needs updating */
 	for (guint i = 0; i < gs_app_list_length (list_apps); i++) {
 		GsApp *app = gs_app_list_index (list_apps, i);
-		if (gs_app_has_quirk (app, AS_APP_QUIRK_NEEDS_REBOOT))
+		if (gs_app_has_quirk (app, GS_APP_QUIRK_NEEDS_REBOOT))
 			need_restart_cnt++;
 	}
 
@@ -223,14 +216,14 @@ _build_autoupdated_notification (GsUpdateMonitor *monitor, GsAppList *list)
 			/* TRANSLATORS: apps were auto-updated and restart is required */
 			title = g_strdup_printf (ngettext ("%u Application Updated — Restart Required",
 			                                   "%u Applications Updated — Restart Required",
-			                                   gs_app_list_length (list)),
-			                         gs_app_list_length (list));
+			                                   gs_app_list_length (list_apps)),
+			                         gs_app_list_length (list_apps));
 		} else {
 			/* TRANSLATORS: apps were auto-updated */
 			title = g_strdup_printf (ngettext ("%u Application Updated",
 			                                   "%u Applications Updated",
-			                                   gs_app_list_length (list)),
-			                         gs_app_list_length (list));
+			                                   gs_app_list_length (list_apps)),
+			                         gs_app_list_length (list_apps));
 		}
 	}
 
@@ -323,6 +316,8 @@ _should_auto_update (GsApp *app)
 		return FALSE;
 	if (gs_app_get_kind (app) == AS_APP_KIND_FIRMWARE)
 		return FALSE;
+	if (gs_app_has_quirk (app, GS_APP_QUIRK_NEW_PERMISSIONS))
+		return FALSE;
 	return TRUE;
 }
 
@@ -332,7 +327,8 @@ download_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 	GsUpdateMonitor *monitor = GS_UPDATE_MONITOR (data);
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsAppList) list = NULL;
-	g_autoptr(GsAppList) list2 = NULL;
+	g_autoptr(GsAppList) update_online = NULL;
+	g_autoptr(GsAppList) update_offline = NULL;
 
 	/* get result */
 	list = gs_plugin_loader_job_process_finish (GS_PLUGIN_LOADER (object), res, &error);
@@ -342,19 +338,23 @@ download_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 		return;
 	}
 
-	/* install any apps that can be installed LIVE */
-	list2 = gs_app_list_new ();
+	update_online = gs_app_list_new ();
+	update_offline = gs_app_list_new ();
 	for (guint i = 0; i < gs_app_list_length (list); i++) {
 		GsApp *app = gs_app_list_index (list, i);
 		if (_should_auto_update (app)) {
 			g_debug ("auto-updating %s", gs_app_get_unique_id (app));
-			gs_app_list_add (list2, app);
+			gs_app_list_add (update_online, app);
+		} else {
+			gs_app_list_add (update_offline, app);
 		}
 	}
-	if (gs_app_list_length (list2) > 0) {
+
+	/* install any apps that can be installed LIVE */
+	if (gs_app_list_length (update_online) > 0) {
 		g_autoptr(GsPluginJob) plugin_job = NULL;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_UPDATE,
-						 "list", list2,
+						 "list", update_online,
 						 NULL);
 		gs_plugin_loader_job_process_async (monitor->plugin_loader,
 						    plugin_job,
@@ -362,6 +362,14 @@ download_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 						    update_finished_cb,
 						    monitor);
 	}
+
+	/* show a notification for offline updates */
+	if (gs_app_list_length (update_offline) > 0) {
+		if (has_important_updates (update_offline) ||
+		    no_updates_for_a_week (monitor)) {
+			notify_offline_update_available (monitor);
+		}
+	}
 }
 
 static void
@@ -408,8 +416,7 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 	g_debug ("got %u updates", gs_app_list_length (apps));
 
 	/* download any updates if auto-updates are turned on */
-	if (download_updates_data->mode == GS_UPDATE_MONITOR_MODE_DO_AUTOUPDATES &&
-	    g_settings_get_boolean (monitor->settings, "download-updates")) {
+	if (g_settings_get_boolean (monitor->settings, "download-updates")) {
 		g_autoptr(GsPluginJob) plugin_job = NULL;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_DOWNLOAD,
 						 "list", apps,
@@ -420,12 +427,12 @@ get_updates_finished_cb (GObject *object, GAsyncResult *res, gpointer data)
 						    monitor->cancellable,
 						    download_finished_cb,
 						    monitor);
-		return;
-	}
-
-	if (has_important_updates (apps) ||
-	    no_updates_for_a_week (monitor)) {
-		notify_offline_update_available (monitor);
+	} else {
+		/* notify immediately if auto-updates are turned off */
+		if (has_important_updates (apps) ||
+		    no_updates_for_a_week (monitor)) {
+			notify_offline_update_available (monitor);
+		}
 	}
 }
 
@@ -551,7 +558,7 @@ get_upgrades_finished_cb (GObject *object,
 }
 
 static void
-get_updates (GsUpdateMonitor *monitor, GsUpdateMonitorMode mode)
+get_updates (GsUpdateMonitor *monitor)
 {
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 	g_autoptr(DownloadUpdatesData) download_updates_data = NULL;
@@ -564,7 +571,6 @@ get_updates (GsUpdateMonitor *monitor, GsUpdateMonitorMode mode)
 
 	download_updates_data = g_slice_new0 (DownloadUpdatesData);
 	download_updates_data->monitor = g_object_ref (monitor);
-	download_updates_data->mode = mode;
 
 	/* NOTE: this doesn't actually do any network access */
 	g_debug ("Getting updates");
@@ -582,7 +588,7 @@ get_updates (GsUpdateMonitor *monitor, GsUpdateMonitorMode mode)
 void
 gs_update_monitor_autoupdate (GsUpdateMonitor *monitor)
 {
-	get_updates (monitor, GS_UPDATE_MONITOR_MODE_DO_AUTOUPDATES);
+	get_updates (monitor);
 }
 
 static void
@@ -646,7 +652,7 @@ refresh_cache_finished_cb (GObject *object,
 	g_settings_set (monitor->settings, "check-timestamp", "x",
 	                g_date_time_to_unix (now));
 
-	get_updates (monitor, GS_UPDATE_MONITOR_MODE_DO_AUTOUPDATES);
+	get_updates (monitor);
 }
 
 typedef enum {
@@ -825,14 +831,6 @@ network_available_notify_cb (GsPluginLoader *plugin_loader,
 	check_updates (monitor);
 }
 
-static void
-updates_changed_cb (GsPluginLoader *plugin_loader, GsUpdateMonitor *monitor)
-{
-	/* when the list of downloaded-and-ready-to-go updates changes get the
-	 * new list and perhaps show/hide the notification */
-	get_updates (monitor, GS_UPDATE_MONITOR_MODE_NONE);
-}
-
 static void
 get_updates_historical_cb (GObject *object, GAsyncResult *res, gpointer data)
 {
@@ -1111,9 +1109,6 @@ gs_update_monitor_dispose (GObject *object)
 		monitor->cleanup_notifications_id = 0;
 	}
 	if (monitor->plugin_loader != NULL) {
-		g_signal_handlers_disconnect_by_func (monitor->plugin_loader,
-		                                      updates_changed_cb,
-		                                      monitor);
 		g_signal_handlers_disconnect_by_func (monitor->plugin_loader,
 						      network_available_notify_cb,
 						      monitor);
@@ -1154,8 +1149,6 @@ gs_update_monitor_new (GsApplication *application)
 	g_application_hold (monitor->application);
 
 	monitor->plugin_loader = gs_application_get_plugin_loader (application);
-	g_signal_connect (monitor->plugin_loader, "updates-changed",
-			  G_CALLBACK (updates_changed_cb), monitor);
 	g_signal_connect (monitor->plugin_loader, "notify::allow-updates",
 			  G_CALLBACK (allow_updates_notify_cb), monitor);
 	g_signal_connect (monitor->plugin_loader, "notify::network-available",
